/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_DL3Y.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_DL3Y *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_DL3Y_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_DL3Y));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_DL3Y(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_DL3Y_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_DL3Y));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_DL3Y(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_DL3Y_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_DL3Y();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_DL3Y::Heavy_WSTD_DL3Y(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_kJh0SaDR);
  numBytes += sLine_init(&sLine_3rZMlBZo);
  numBytes += sLine_init(&sLine_LJQWHNTj);
  numBytes += sLine_init(&sLine_tGrr9cPb);
  numBytes += sLine_init(&sLine_vXzyv70z);
  numBytes += sBiquad_init(&sBiquad_s_iH3q8acw);
  numBytes += sLine_init(&sLine_7T7RPtZX);
  numBytes += sLine_init(&sLine_8Ibo082F);
  numBytes += sLine_init(&sLine_HD68qRAu);
  numBytes += sLine_init(&sLine_2OdqylDk);
  numBytes += sBiquad_init(&sBiquad_s_4bkPUMBw);
  numBytes += sLine_init(&sLine_39iA6lvR);
  numBytes += sLine_init(&sLine_2OwiFIU4);
  numBytes += sLine_init(&sLine_Hur7B5gv);
  numBytes += sLine_init(&sLine_C5qy58mo);
  numBytes += sLine_init(&sLine_8PYhkDAo);
  numBytes += sBiquad_init(&sBiquad_s_8ghEZtJt);
  numBytes += sLine_init(&sLine_eXhDUNtk);
  numBytes += sLine_init(&sLine_D1JuR0s9);
  numBytes += sLine_init(&sLine_vwerc7LU);
  numBytes += sLine_init(&sLine_SOrwhjhI);
  numBytes += sLine_init(&sLine_1I0JV0CW);
  numBytes += sBiquad_init(&sBiquad_s_rPaoWpTN);
  numBytes += sLine_init(&sLine_tMVolzDU);
  numBytes += sLine_init(&sLine_v3YC6iS3);
  numBytes += sLine_init(&sLine_JciVd4YJ);
  numBytes += sLine_init(&sLine_ReJFyme2);
  numBytes += sBiquad_init(&sBiquad_s_4aoTeWS9);
  numBytes += sLine_init(&sLine_W71E820s);
  numBytes += sLine_init(&sLine_SKZfHngI);
  numBytes += sLine_init(&sLine_7VUakwb1);
  numBytes += sLine_init(&sLine_6J7Y9NNA);
  numBytes += sLine_init(&sLine_ZZ007Gc4);
  numBytes += sBiquad_init(&sBiquad_s_2Pu1Sj2P);
  numBytes += sLine_init(&sLine_QUo1G4gS);
  numBytes += sTabread_init(&sTabread_jCyYXfUp, &hTable_2yjteFNY, true);
  numBytes += sLine_init(&sLine_wxptlJJc);
  numBytes += sLine_init(&sLine_JB0Xe7Ux);
  numBytes += sTabread_init(&sTabread_gumrO5pJ, &hTable_DbibR2UO, true);
  numBytes += sLine_init(&sLine_U9Cfb8gy);
  numBytes += sRPole_init(&sRPole_9RgIJVyK);
  numBytes += sDel1_init(&sDel1_0uuBOuoz);
  numBytes += sTabwrite_init(&sTabwrite_bl2DJOVj, &hTable_2yjteFNY);
  numBytes += sRPole_init(&sRPole_bwXX3iP6);
  numBytes += sDel1_init(&sDel1_SddVIMQI);
  numBytes += sTabwrite_init(&sTabwrite_4yWDat1p, &hTable_DbibR2UO);
  numBytes += sLine_init(&sLine_gKmidHOR);
  numBytes += sLine_init(&sLine_yENWJgcS);
  numBytes += sRPole_init(&sRPole_FUsJuoDb);
  numBytes += sEnv_init(&sEnv_G3Y4FPrS, 1024, 512);
  numBytes += sRPole_init(&sRPole_wXo36che);
  numBytes += sLine_init(&sLine_TptN4Ux4);
  numBytes += sLine_init(&sLine_Smhz4MkN);
  numBytes += sRPole_init(&sRPole_ZdFfhGA4);
  numBytes += sEnv_init(&sEnv_DusZaa7A, 1024, 512);
  numBytes += sRPole_init(&sRPole_1RO4mIhQ);
  numBytes += sLine_init(&sLine_PLysKHh7);
  numBytes += sTabread_init(&sTabread_x2U2t9Yg, &hTable_O5bUfp1K, true);
  numBytes += sLine_init(&sLine_P1OdeSXT);
  numBytes += sLine_init(&sLine_dxPE8zkt);
  numBytes += sTabread_init(&sTabread_ofzDWlSh, &hTable_LDmV5UoC, true);
  numBytes += sLine_init(&sLine_u6DLfBsS);
  numBytes += sRPole_init(&sRPole_xktuHp75);
  numBytes += sDel1_init(&sDel1_CaARGbMB);
  numBytes += sTabwrite_init(&sTabwrite_ss27HoFU, &hTable_O5bUfp1K);
  numBytes += sRPole_init(&sRPole_nVyVfIfG);
  numBytes += sDel1_init(&sDel1_JZYAJ2WN);
  numBytes += sTabwrite_init(&sTabwrite_41AIsxpP, &hTable_LDmV5UoC);
  numBytes += sLine_init(&sLine_8LHM389H);
  numBytes += sLine_init(&sLine_XmaejfVE);
  numBytes += sRPole_init(&sRPole_KwHRoUpg);
  numBytes += sEnv_init(&sEnv_xvFSZtWZ, 1024, 512);
  numBytes += sRPole_init(&sRPole_7hjTthTM);
  numBytes += sLine_init(&sLine_Kn7buoVW);
  numBytes += sLine_init(&sLine_xKGSX7HE);
  numBytes += sRPole_init(&sRPole_oIlmLN5h);
  numBytes += sEnv_init(&sEnv_cj5rytmK, 1024, 512);
  numBytes += sRPole_init(&sRPole_38SaWtO1);
  numBytes += sLine_init(&sLine_EqXIZ3nf);
  numBytes += sTabread_init(&sTabread_EhqIz5NI, &hTable_29VDm9Cb, true);
  numBytes += sLine_init(&sLine_9NHUefnY);
  numBytes += sLine_init(&sLine_7VwmSCXX);
  numBytes += sTabread_init(&sTabread_lMZcOwpF, &hTable_NizuKVeo, true);
  numBytes += sLine_init(&sLine_9BxoFLfS);
  numBytes += sRPole_init(&sRPole_lHtpClCG);
  numBytes += sDel1_init(&sDel1_NQs5q9Wy);
  numBytes += sTabwrite_init(&sTabwrite_MLrMEAIn, &hTable_29VDm9Cb);
  numBytes += sRPole_init(&sRPole_Yw3t4j0K);
  numBytes += sDel1_init(&sDel1_7fqCVLk2);
  numBytes += sTabwrite_init(&sTabwrite_bbqCH68Y, &hTable_NizuKVeo);
  numBytes += sLine_init(&sLine_KkmMQoEr);
  numBytes += sLine_init(&sLine_ebHEI9Se);
  numBytes += sRPole_init(&sRPole_PqptoNrE);
  numBytes += sEnv_init(&sEnv_j98bGlBF, 1024, 512);
  numBytes += sRPole_init(&sRPole_otrXE8X6);
  numBytes += sLine_init(&sLine_mwRC6e9e);
  numBytes += sLine_init(&sLine_My6wt8xb);
  numBytes += sRPole_init(&sRPole_FWZQa5dY);
  numBytes += sEnv_init(&sEnv_HHaHgeMa, 1024, 512);
  numBytes += sRPole_init(&sRPole_lrVBjNas);
  numBytes += cVar_init_f(&cVar_vQXLxu8f, 0.0f);
  numBytes += cVar_init_f(&cVar_SJM0ySRy, 0.0f);
  numBytes += cVar_init_f(&cVar_cIej8H7r, 0.0f);
  numBytes += cVar_init_f(&cVar_e7j6nn4t, 0.0f);
  numBytes += cSlice_init(&cSlice_XWpAxCo4, 1, -1);
  numBytes += cVar_init_f(&cVar_RT1nkx3t, 1337.0f);
  numBytes += cVar_init_f(&cVar_c8OfgimG, 0.0f);
  numBytes += cIf_init(&cIf_YfVeaCr8, false);
  numBytes += cIf_init(&cIf_GJo5lcsc, false);
  numBytes += cBinop_init(&cBinop_9sMrwzn0, 0.0f); // __pow
  numBytes += cIf_init(&cIf_CRMRuevC, false);
  numBytes += cBinop_init(&cBinop_1WyX1zgS, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_o6lozz7e, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_8ehsHhwX, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_uBb2kzOA, 0.0f);
  numBytes += cIf_init(&cIf_76eocPrP, false);
  numBytes += cIf_init(&cIf_n6nCUc6w, false);
  numBytes += cBinop_init(&cBinop_7642dZmg, 0.0f); // __pow
  numBytes += cIf_init(&cIf_UfQmq1Wg, false);
  numBytes += cBinop_init(&cBinop_DTqwU6UE, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_Vl2gFRhl, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_ChdDF13X, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_hA9VnOW7, 0.0f);
  numBytes += cIf_init(&cIf_ISzTnc6M, false);
  numBytes += cIf_init(&cIf_RXa3VfIx, false);
  numBytes += cBinop_init(&cBinop_5XGBi0ah, 0.0f); // __pow
  numBytes += cIf_init(&cIf_Hehf9QHZ, false);
  numBytes += cBinop_init(&cBinop_OijbtuSl, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_V9OAvCfs, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_RlGkiQZQ, -15.0f); // __eq
  numBytes += cIf_init(&cIf_cg7vdtCw, false);
  numBytes += cSlice_init(&cSlice_3gehNZ1d, 1, -1);
  numBytes += cVar_init_f(&cVar_7nIZcxWA, 0.0f);
  numBytes += cSlice_init(&cSlice_fEkxyRzM, 1, -1);
  numBytes += cVar_init_f(&cVar_lTBlOzWF, 0.0f);
  numBytes += cSlice_init(&cSlice_KD50BumP, 1, -1);
  numBytes += cVar_init_f(&cVar_73E1FTrW, 0.0f);
  numBytes += cSlice_init(&cSlice_mybj2V2A, 1, -1);
  numBytes += cVar_init_f(&cVar_jygwXD0R, 0.313f);
  numBytes += cBinop_init(&cBinop_luE7TrBg, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_DXOSJutD, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_ooXoCPJh, 0.0f);
  numBytes += cVar_init_f(&cVar_IIfnvSIG, 1337.0f);
  numBytes += cVar_init_f(&cVar_JvVbAp6R, 0.3f);
  numBytes += cBinop_init(&cBinop_mQ4si676, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_629klerW, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_I9FxRK59, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_6kCrFwQ6, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ZuwmQ9Yv, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_c4CudSzg, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Ftex1NQH, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_y6a8tGuM, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_vtpl1cdB, 0.0f);
  numBytes += cVar_init_f(&cVar_WVQT39BW, 1337.0f);
  numBytes += cVar_init_f(&cVar_rvIbbYXm, 0.313f);
  numBytes += cBinop_init(&cBinop_l9Ia4XUM, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_RybKQ2hC, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_bYfshN5r, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ezAXfaar, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_PUg5a1Lo, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_kLUulv6e, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_vvfaVJ7N, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_W41grYbX, 0.0f);
  numBytes += cVar_init_f(&cVar_MxZQKyRp, 1037.0f);
  numBytes += cVar_init_f(&cVar_12gx9RtV, 0.4f);
  numBytes += cBinop_init(&cBinop_uo4MLQxX, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_eB4ctzYN, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_7EKdyZKD, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_gMhXHIF6, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_eyEYNHlU, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_P61wr1HY, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_4BUwEWtU, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_znI3yxIM, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_cXX7VPBI, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_cYzdC61n, 1, -1);
  numBytes += cVar_init_f(&cVar_gU9dF0aN, 1337.0f);
  numBytes += cVar_init_f(&cVar_Ixb8M9k4, 0.0f);
  numBytes += cIf_init(&cIf_mVRzg57y, false);
  numBytes += cIf_init(&cIf_AicbegzZ, false);
  numBytes += cBinop_init(&cBinop_jdBc9Hp5, 0.0f); // __pow
  numBytes += cIf_init(&cIf_U3RC49xJ, false);
  numBytes += cBinop_init(&cBinop_gHX8x5BH, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_xbyHKnpl, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_z3DRHios, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_4N3znSAu, 0.0f);
  numBytes += cIf_init(&cIf_LOcTIa3h, false);
  numBytes += cIf_init(&cIf_TNz4Nvfa, false);
  numBytes += cBinop_init(&cBinop_3u9iMR0r, 0.0f); // __pow
  numBytes += cIf_init(&cIf_eEaE3f6L, false);
  numBytes += cBinop_init(&cBinop_X5SrpjSJ, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_u1LlZxdD, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_6dUv23f7, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_yNeTV4qH, 0.0f);
  numBytes += cIf_init(&cIf_R9ZjHqyw, false);
  numBytes += cIf_init(&cIf_c5281j2s, false);
  numBytes += cBinop_init(&cBinop_tQ1MwGyp, 0.0f); // __pow
  numBytes += cIf_init(&cIf_kWzwAccD, false);
  numBytes += cBinop_init(&cBinop_b8iapbcE, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_R32yFgy2, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_RbsDpD06, -15.0f); // __eq
  numBytes += cIf_init(&cIf_csVmJY7u, false);
  numBytes += cSlice_init(&cSlice_CkEn2SHD, 1, -1);
  numBytes += cVar_init_f(&cVar_HGn0lA2X, 0.0f);
  numBytes += cSlice_init(&cSlice_n7MZwLFB, 1, -1);
  numBytes += cVar_init_f(&cVar_gOr7IVzh, 0.0f);
  numBytes += cSlice_init(&cSlice_NDTEJgpr, 1, -1);
  numBytes += cVar_init_f(&cVar_coZegqn7, 0.0f);
  numBytes += cSlice_init(&cSlice_HO0jIDnf, 1, -1);
  numBytes += cVar_init_f(&cVar_rn2jMZab, 0.313f);
  numBytes += cBinop_init(&cBinop_DNr4o6Ui, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_lhSLtJOz, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_anS8ivGj, 0.0f);
  numBytes += cVar_init_f(&cVar_S4B3aV9u, 1337.0f);
  numBytes += cVar_init_f(&cVar_zeVfTzPK, 0.3f);
  numBytes += cBinop_init(&cBinop_NK7R2OhK, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_36C0tLaK, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ErAikW72, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_SlpJtgtP, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_8vo1JQ9S, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Zw4k9hGL, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_1gfwFBW3, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_5vRZbH0t, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_lGb1r5Be, 0.0f);
  numBytes += cVar_init_f(&cVar_XGikqTeD, 1337.0f);
  numBytes += cVar_init_f(&cVar_y7xLO2x2, 0.313f);
  numBytes += cBinop_init(&cBinop_D6NXiTna, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_4pHYAhc8, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_bVnpWwVB, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_oo3nV6Bx, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_EulpuXcs, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_1fm3ifgQ, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_GDVOzYKC, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_1slehZPC, 0.0f);
  numBytes += cVar_init_f(&cVar_2dt5mPi6, 1037.0f);
  numBytes += cVar_init_f(&cVar_m5Nb5vJp, 0.4f);
  numBytes += cBinop_init(&cBinop_lheuA62s, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_XNjMHAA5, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_5LRksFpp, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_AsvU4Yxu, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_QHeij0FQ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_h8BHd3GM, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_kDmdw5sM, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_aJqNvZb4, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_d6xR9yDw, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_N4sNaUrM, 5705.6f);
  numBytes += cVar_init_f(&cVar_nAp8jIWV, 313.3f);
  numBytes += cBinop_init(&cBinop_ddhNX5Wt, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_gcJOyEwN, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_UwEYCdwA, 0.0f); // __div
  numBytes += cVar_init_f(&cVar_4D84bAof, 0.0f);
  numBytes += cVar_init_f(&cVar_4xLNnZQa, 0.0f);
  numBytes += cVar_init_f(&cVar_1fzLLmHs, 0.0f);
  numBytes += cVar_init_f(&cVar_eGxjHHDh, 0.0f);
  numBytes += cVar_init_f(&cVar_89NvpIVT, 0.0f);
  numBytes += cVar_init_f(&cVar_2kMIXZHK, 0.0f);
  numBytes += cVar_init_f(&cVar_Rh2uejpk, 0.0f);
  numBytes += cVar_init_f(&cVar_ohIdpqxw, 0.0f);
  numBytes += cVar_init_f(&cVar_57L0GOvH, 0.0f);
  numBytes += cVar_init_f(&cVar_boeOssgK, 0.0f);
  numBytes += cVar_init_f(&cVar_xqeCbU0Y, 0.0f);
  numBytes += cVar_init_f(&cVar_dYK79nh6, 0.0f);
  numBytes += cSlice_init(&cSlice_g9plPwMc, 1, -1);
  numBytes += cVar_init_f(&cVar_a1w8mscN, 0.5f);
  numBytes += cSlice_init(&cSlice_ffnmdhaZ, 1, -1);
  numBytes += cVar_init_f(&cVar_Ijm8onJJ, 0.2f);
  numBytes += cSlice_init(&cSlice_1LcUvFYT, 1, -1);
  numBytes += cVar_init_f(&cVar_5McP8Xud, 500.0f);
  numBytes += sVarf_init(&sVarf_2WmMyujj, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_5MV5sneD, 600.0f);
  numBytes += cBinop_init(&cBinop_DeVtGCsC, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_q9rV8ZfT, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_GOw4Ag0B, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_xVdqLggW, 600.0f);
  numBytes += cBinop_init(&cBinop_zcwFxg05, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_xQhBofaa, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_ayHvAT7o, 4000.0f);
  numBytes += cBinop_init(&cBinop_0fqpKSek, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_ybxY8DX1, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_GGZvI91M, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_fJRcAHjS, 4000.0f);
  numBytes += cBinop_init(&cBinop_0UGBiQ3u, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_XZgxXwpV, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_oWhjsW4v, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_O17I0DjY, false);
  numBytes += cBinop_init(&cBinop_ghbeG9ck, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_JQ0GI58W, 20.0f);
  numBytes += cBinop_init(&cBinop_GOWhVNMk, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_UPTvDAyt, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_PufPqmnj, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_6QUsvZ3b, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_KAAN4WWh, false);
  numBytes += cBinop_init(&cBinop_gWFoOmHd, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_tRIBZwXh, 20.0f);
  numBytes += cBinop_init(&cBinop_VB5f24yr, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_RBN38R9K, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_p3X47L0v, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ncBUKKHR, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_U2EMZAPS, 1, -1);
  numBytes += cVar_init_f(&cVar_9e2Rbmrf, 0.25f);
  numBytes += cDelay_init(this, &cDelay_SRYDGyav, 0.0f);
  numBytes += cDelay_init(this, &cDelay_xAgVxOv9, 0.0f);
  numBytes += hTable_init(&hTable_2yjteFNY, 256);
  numBytes += cTabhead_init(&cTabhead_qoIw022e, &hTable_2yjteFNY);
  numBytes += cVar_init_s(&cVar_3ShYUhrc, "del-1349-delayL");
  numBytes += cDelay_init(this, &cDelay_CwiapWJc, 0.0f);
  numBytes += cDelay_init(this, &cDelay_9rafBBVp, 0.0f);
  numBytes += cBinop_init(&cBinop_Fk4KiUhD, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_8DEkgxCV, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_MPXE6VMe, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_2Re6EYdM, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_cZXt7FX8, 0.0f);
  numBytes += cDelay_init(this, &cDelay_o2seiopm, 0.0f);
  numBytes += hTable_init(&hTable_DbibR2UO, 256);
  numBytes += cTabhead_init(&cTabhead_ofqcEpTF, &hTable_DbibR2UO);
  numBytes += cVar_init_s(&cVar_YxyQ7ffb, "del-1349-delayR");
  numBytes += cDelay_init(this, &cDelay_iQ5GNxQJ, 0.0f);
  numBytes += cDelay_init(this, &cDelay_VXoKzm8q, 0.0f);
  numBytes += cBinop_init(&cBinop_P9SSFtGk, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_dJGUUWNq, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_D844c03i, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_ZYnOdmJK, 0.0f); // __sub
  numBytes += sVarf_init(&sVarf_jxnIX1t7, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_M0aDGRLh, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_KX9ak6pE, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_1A3Vwm0G, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_olchhRzN, 1, -1);
  numBytes += cVar_init_f(&cVar_7ZmVbcnL, 0.5f);
  numBytes += cSlice_init(&cSlice_DXi8Hb5t, 1, -1);
  numBytes += cVar_init_f(&cVar_n07xxocL, 0.2f);
  numBytes += cSlice_init(&cSlice_TYZ40Pi2, 1, -1);
  numBytes += cVar_init_f(&cVar_w1bg2pdl, 500.0f);
  numBytes += sVarf_init(&sVarf_dfD9NjQc, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_VCun9Kn1, 600.0f);
  numBytes += cBinop_init(&cBinop_E8okldAt, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_0JFkmAVK, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ES8wOcWX, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_LY4gasBz, 600.0f);
  numBytes += cBinop_init(&cBinop_lvHg3VUW, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_Sor2xfXa, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_YWFkZvpr, 4000.0f);
  numBytes += cBinop_init(&cBinop_C6ILaBMj, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_e3gGVxVd, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_dvSTIikI, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_Vdjluy0T, 4000.0f);
  numBytes += cBinop_init(&cBinop_IeugtuA0, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_VAdL1307, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Q2WXAtNx, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_oXcl5e9D, false);
  numBytes += cBinop_init(&cBinop_tRDSX8gU, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_UHcTmef7, 20.0f);
  numBytes += cBinop_init(&cBinop_vn9oV0AM, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_U4O6tKli, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_XzGRbfNn, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_c2ai5P5T, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_0I3HwFIb, false);
  numBytes += cBinop_init(&cBinop_T7s5f5xD, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_abNhgbxk, 20.0f);
  numBytes += cBinop_init(&cBinop_Zw8D6nCM, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_sGj9JT6t, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_9Dn7f0SQ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_CKLGQAB3, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_v6uyKJIG, 1, -1);
  numBytes += cVar_init_f(&cVar_tCuMRKRD, 0.25f);
  numBytes += cDelay_init(this, &cDelay_rDOgMrQO, 0.0f);
  numBytes += cDelay_init(this, &cDelay_fGsUJrvY, 0.0f);
  numBytes += hTable_init(&hTable_O5bUfp1K, 256);
  numBytes += cTabhead_init(&cTabhead_73d4VvaX, &hTable_O5bUfp1K);
  numBytes += cVar_init_s(&cVar_lqM360pS, "del-1428-delayL");
  numBytes += cDelay_init(this, &cDelay_bhecObMw, 0.0f);
  numBytes += cDelay_init(this, &cDelay_tEuSutET, 0.0f);
  numBytes += cBinop_init(&cBinop_UVn2p2BT, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_KhKnbVFP, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_23vxXZhO, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_zIEWU4mZ, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_xI4EAKlW, 0.0f);
  numBytes += cDelay_init(this, &cDelay_tTM2oW6M, 0.0f);
  numBytes += hTable_init(&hTable_LDmV5UoC, 256);
  numBytes += cTabhead_init(&cTabhead_1chPiyzJ, &hTable_LDmV5UoC);
  numBytes += cVar_init_s(&cVar_eK4Jarzo, "del-1428-delayR");
  numBytes += cDelay_init(this, &cDelay_zWdrJ0S6, 0.0f);
  numBytes += cDelay_init(this, &cDelay_lXiVLbXV, 0.0f);
  numBytes += cBinop_init(&cBinop_eoTNAHKC, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_FlGf6t36, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_x57YWzXr, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_6CmeSeSm, 0.0f); // __sub
  numBytes += sVarf_init(&sVarf_g6ERgTmd, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_QADJ3qC3, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_3u9p6ATb, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_fYZFrxkc, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_B8JZrqiG, 1, -1);
  numBytes += cVar_init_f(&cVar_kGDtnefe, 0.5f);
  numBytes += cSlice_init(&cSlice_uL2SJ8Wb, 1, -1);
  numBytes += cVar_init_f(&cVar_K9KoNGey, 0.2f);
  numBytes += cSlice_init(&cSlice_KfEos8Sl, 1, -1);
  numBytes += cVar_init_f(&cVar_nWohq1bl, 500.0f);
  numBytes += sVarf_init(&sVarf_xEOxzlSI, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_VHt34opl, 600.0f);
  numBytes += cBinop_init(&cBinop_IcwjBYnM, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_Mey2ASBG, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_CzKj2tcE, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_fCisIMAa, 600.0f);
  numBytes += cBinop_init(&cBinop_v58GiVeq, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_8FkfIvOI, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_EDmkZx5f, 4000.0f);
  numBytes += cBinop_init(&cBinop_XlTIEiWL, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_ezNDdIIq, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_eSQ9AtSo, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_Tq8W4U1G, 4000.0f);
  numBytes += cBinop_init(&cBinop_st5VIIqh, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_qqArUhbb, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Zb1HqML6, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_jBe0S5nP, false);
  numBytes += cBinop_init(&cBinop_78Sn05uf, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_IIGjUzKt, 20.0f);
  numBytes += cBinop_init(&cBinop_1wQ7TqQp, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_FysH86lk, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_kWbeYKlB, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_6vPnDkx4, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_SOXXzuiY, false);
  numBytes += cBinop_init(&cBinop_2sdyeF10, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_I9IOh9DM, 20.0f);
  numBytes += cBinop_init(&cBinop_DYar3h2O, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_uli9YSYT, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_TAY4jR9W, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_QEkxL30X, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_gJeOSgX0, 1, -1);
  numBytes += cVar_init_f(&cVar_R9WLaEtD, 0.25f);
  numBytes += cDelay_init(this, &cDelay_wJyZhAVY, 0.0f);
  numBytes += cDelay_init(this, &cDelay_4dJMnwyg, 0.0f);
  numBytes += hTable_init(&hTable_29VDm9Cb, 256);
  numBytes += cTabhead_init(&cTabhead_al0QVeVO, &hTable_29VDm9Cb);
  numBytes += cVar_init_s(&cVar_mWUiw2VE, "del-1507-delayL");
  numBytes += cDelay_init(this, &cDelay_bbNJojpM, 0.0f);
  numBytes += cDelay_init(this, &cDelay_ROOQPIuK, 0.0f);
  numBytes += cBinop_init(&cBinop_yjLQMjOP, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_2LxMMVPi, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_qwfV3RnL, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_zuP89wX0, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_0F7mRIQR, 0.0f);
  numBytes += cDelay_init(this, &cDelay_fRYPmMFu, 0.0f);
  numBytes += hTable_init(&hTable_NizuKVeo, 256);
  numBytes += cTabhead_init(&cTabhead_JEowga8n, &hTable_NizuKVeo);
  numBytes += cVar_init_s(&cVar_8N75hqps, "del-1507-delayR");
  numBytes += cDelay_init(this, &cDelay_xC5meA2z, 0.0f);
  numBytes += cDelay_init(this, &cDelay_Mch09k6i, 0.0f);
  numBytes += cBinop_init(&cBinop_7SPdBQ8H, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_oZAmLeSi, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_gVfdMoL9, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_WLpFsj3y, 0.0f); // __sub
  numBytes += sVarf_init(&sVarf_U4oOBMua, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_QuuU7Onv, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_7BBxDAhS, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_8vtgrIRv, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_POgMvsVH, 1.0f);
  numBytes += cIf_init(&cIf_BUhKXsF3, false);
  numBytes += cIf_init(&cIf_U6olv1Tr, false);
  numBytes += cVar_init_f(&cVar_PFBMaJEw, 0.0f);
  numBytes += cVar_init_f(&cVar_QxrH9wab, 0.0f);
  numBytes += cVar_init_f(&cVar_cQe4j39W, 1.0f);
  numBytes += cIf_init(&cIf_8YVPzwcd, false);
  numBytes += cIf_init(&cIf_pHVc6bkb, false);
  numBytes += cVar_init_f(&cVar_cjXW0dFB, 0.0f);
  numBytes += cVar_init_f(&cVar_zGUgKoEG, 0.0f);
  numBytes += cVar_init_f(&cVar_X3UyUhOh, 1.0f);
  numBytes += cIf_init(&cIf_UPP0FQG4, false);
  numBytes += cIf_init(&cIf_4nIYU2uh, false);
  numBytes += cVar_init_f(&cVar_BcvNmYES, 0.0f);
  numBytes += cVar_init_f(&cVar_Xwo59aWt, 0.0f);
  numBytes += cVar_init_f(&cVar_V4EQthnS, 60000.0f);
  numBytes += cVar_init_f(&cVar_mtRGjX1g, 500.0f);
  numBytes += cSlice_init(&cSlice_aGFgnniI, 1, -1);
  numBytes += cSlice_init(&cSlice_IVosIeED, 1, -1);
  numBytes += cVar_init_f(&cVar_fqztuJ79, 0.0f);
  numBytes += cIf_init(&cIf_OkNDHXsM, false);
  numBytes += cBinop_init(&cBinop_a5iE5kTY, 0.0f); // __neq
  numBytes += cVar_init_f(&cVar_f6VxDIRT, 120.0f);
  numBytes += cBinop_init(&cBinop_io2LWTEM, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_iMrLZHfK, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_QKZbj1QA, 60000.0f);
  numBytes += cVar_init_f(&cVar_ytMfq5jm, 500.0f);
  numBytes += cSlice_init(&cSlice_KdWVisBO, 1, -1);
  numBytes += cSlice_init(&cSlice_z9osDnah, 1, -1);
  numBytes += cVar_init_f(&cVar_l5sk1Gca, 0.0f);
  numBytes += cIf_init(&cIf_rwUNOg5Z, false);
  numBytes += cBinop_init(&cBinop_iAVPaBaF, 0.0f); // __neq
  numBytes += cVar_init_f(&cVar_cTlYKZLS, 120.0f);
  numBytes += cBinop_init(&cBinop_omn0lBrZ, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_AlhX2Zva, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_xW9sznDx, 60000.0f);
  numBytes += cVar_init_f(&cVar_FrtmmIEg, 500.0f);
  numBytes += cSlice_init(&cSlice_XIZpCDOg, 1, -1);
  numBytes += cSlice_init(&cSlice_3liwz9dW, 1, -1);
  numBytes += cVar_init_f(&cVar_IKh7Xang, 0.0f);
  numBytes += cIf_init(&cIf_Qvcvv7xR, false);
  numBytes += cBinop_init(&cBinop_XL8DP6RI, 0.0f); // __neq
  numBytes += cVar_init_f(&cVar_2kdp05y7, 120.0f);
  numBytes += cBinop_init(&cBinop_yst2cxzW, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_nBVfv5np, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_EXzUW1i4, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_a6XN91ud, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_rexWg1zb, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_orsFTQor, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_b9EtPQyV, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_7fvWIELW, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_kJcHolcm, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_fVzWGxEH, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_DutPA6ob, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_9sTivhHL, 0.0f, 0.0f, false);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_DL3Y::~Heavy_WSTD_DL3Y() {
  sEnv_free(&sEnv_G3Y4FPrS);
  sEnv_free(&sEnv_DusZaa7A);
  sEnv_free(&sEnv_xvFSZtWZ);
  sEnv_free(&sEnv_cj5rytmK);
  sEnv_free(&sEnv_j98bGlBF);
  sEnv_free(&sEnv_HHaHgeMa);
  hTable_free(&hTable_2yjteFNY);
  hTable_free(&hTable_DbibR2UO);
  hTable_free(&hTable_O5bUfp1K);
  hTable_free(&hTable_LDmV5UoC);
  hTable_free(&hTable_29VDm9Cb);
  hTable_free(&hTable_NizuKVeo);
}

HvTable *Heavy_WSTD_DL3Y::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0x29B74AF: return &hTable_2yjteFNY; // del-1349-delayL
    case 0x19A00729: return &hTable_DbibR2UO; // del-1349-delayR
    case 0x584C8281: return &hTable_O5bUfp1K; // del-1428-delayL
    case 0x54BF59F6: return &hTable_LDmV5UoC; // del-1428-delayR
    case 0xBCE693A: return &hTable_29VDm9Cb; // del-1507-delayL
    case 0x95A380B3: return &hTable_NizuKVeo; // del-1507-delayR
    default: return nullptr;
  }
}

void Heavy_WSTD_DL3Y::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xC9CE7B11: { // High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_s8GTXBWw_sendMessage);
      break;
    }
    case 0xBB584857: { // High_Cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_RPDIuikB_sendMessage);
      break;
    }
    case 0xACE44B9C: { // High_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_uyhRunyX_sendMessage);
      break;
    }
    case 0xAC5FA57F: { // High_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ChHOzsV4_sendMessage);
      break;
    }
    case 0xDD62B09F: { // High_Sync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_5Z3D4Qmk_sendMessage);
      break;
    }
    case 0xABB0CBCF: { // High_Time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_MJVYJBVc_sendMessage);
      break;
    }
    case 0xAE942A2: { // High_TimeSync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_7QsPqQGX_sendMessage);
      break;
    }
    case 0x87744544: { // Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_au9wZ7Ba_sendMessage);
      break;
    }
    case 0xA2D68920: { // Low_Cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_SbA4RIyY_sendMessage);
      break;
    }
    case 0xDDAB7A0: { // Low_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_CyWpuAUl_sendMessage);
      break;
    }
    case 0x91FEF7A: { // Low_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_VPrsJK72_sendMessage);
      break;
    }
    case 0xFFFEE96: { // Low_Sync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_SmqJZaab_sendMessage);
      break;
    }
    case 0xA3BD8A20: { // Low_Time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Zqw8llW0_sendMessage);
      break;
    }
    case 0x67F58CFB: { // Low_TimeSync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_dXm8qvLS_sendMessage);
      break;
    }
    case 0xBFDC48B6: { // Mid
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_8TORVN1y_sendMessage);
      break;
    }
    case 0x59607D3: { // Mid_Cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Hmo6BoV0_sendMessage);
      break;
    }
    case 0x9B44FA2D: { // Mid_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_yBY5s7bg_sendMessage);
      break;
    }
    case 0x59CF21AC: { // Mid_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_WF52O2bZ_sendMessage);
      break;
    }
    case 0x676FE235: { // Mid_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_1Vgaq1hp_sendMessage);
      break;
    }
    case 0x96E19510: { // Mid_Sync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_YQgm7aSg_sendMessage);
      break;
    }
    case 0xE1DB1774: { // Mid_Time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qabnue4w_sendMessage);
      break;
    }
    case 0xDB67B94E: { // Mid_TimeSync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_sGXL4NVz_sendMessage);
      break;
    }
    case 0x24295C10: { // 1010-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_X4lm9zQV_sendMessage);
      break;
    }
    case 0x3649681E: { // 1010-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_IfqCXE0v_sendMessage);
      break;
    }
    case 0xD5A8E74D: { // 1010-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_oDG18UOJ_sendMessage);
      break;
    }
    case 0x60D6F65: { // 1010-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_46GusISW_sendMessage);
      break;
    }
    case 0x37E92263: { // 1010-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_EDOiQRq1_sendMessage);
      break;
    }
    case 0x2271964: { // 1069-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_MwRny1Wn_sendMessage);
      break;
    }
    case 0xA61C5543: { // 1069-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_jXKP0n8t_sendMessage);
      break;
    }
    case 0x1E13C49D: { // 1069-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_tNHcIIUM_sendMessage);
      break;
    }
    case 0xE7448D12: { // 1110-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_cg9zb3Hx_sendMessage);
      break;
    }
    case 0x5F31ED81: { // 1110-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ooBu7uM3_sendMessage);
      break;
    }
    case 0xC3520438: { // 1110-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_xEqPfHZu_sendMessage);
      break;
    }
    case 0xB2DA8F9A: { // 1151-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_9RfMaMjT_sendMessage);
      break;
    }
    case 0x668DC2C1: { // 1151-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_zZg6JXDR_sendMessage);
      break;
    }
    case 0x413B9F30: { // 1151-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_1XUzBEvj_sendMessage);
      break;
    }
    case 0x845815A0: { // 1163-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qu6k4DPL_sendMessage);
      break;
    }
    case 0x5CD8AF91: { // 1163-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_4YCSqKpW_sendMessage);
      break;
    }
    case 0x188BB7A0: { // 1163-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_MfzTaWKO_sendMessage);
      break;
    }
    case 0xE3BB13E4: { // 1163-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_WRVyVj5l_sendMessage);
      break;
    }
    case 0x3693B415: { // 1163-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_6pXvPuIA_sendMessage);
      break;
    }
    case 0x1A14721E: { // 1222-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_EHKMiKT8_sendMessage);
      break;
    }
    case 0x446DC164: { // 1222-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_QOeucAqD_sendMessage);
      break;
    }
    case 0x32F45A8B: { // 1222-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_uoKpAINg_sendMessage);
      break;
    }
    case 0x1286072C: { // 1263-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_K83qHObA_sendMessage);
      break;
    }
    case 0x7902A17C: { // 1263-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_3fJ0mtQN_sendMessage);
      break;
    }
    case 0x7A57C19C: { // 1263-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_si9cLD9G_sendMessage);
      break;
    }
    case 0x170C9887: { // 1304-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_QUiVWvfz_sendMessage);
      break;
    }
    case 0xED0CBA1C: { // 1304-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_t3codlLV_sendMessage);
      break;
    }
    case 0xDA3A818C: { // 1304-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_GXZFpwJq_sendMessage);
      break;
    }
    case 0x9FC1C9E5: { // 1349-cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_8tzQf64h_sendMessage);
      break;
    }
    case 0x5D7BD4E9: { // 1349-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_1VNiKn07_sendMessage);
      break;
    }
    case 0x371A347A: { // 1349-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_egyAwq39_sendMessage);
      break;
    }
    case 0x810E74BC: { // 1349-time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_91sk2V5X_sendMessage);
      break;
    }
    case 0xCC56B3CF: { // 1428-cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_WDa7pQAv_sendMessage);
      break;
    }
    case 0x499A953B: { // 1428-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_38OO88lJ_sendMessage);
      break;
    }
    case 0xE0E7225B: { // 1428-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_6aXlfFpa_sendMessage);
      break;
    }
    case 0xE6486F5F: { // 1428-time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_wPbN32hU_sendMessage);
      break;
    }
    case 0xF65E8330: { // 1507-cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_W5VFado3_sendMessage);
      break;
    }
    case 0x3B8B5FB8: { // 1507-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_wNZk3dA6_sendMessage);
      break;
    }
    case 0xE5F26E0D: { // 1507-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_nJFkh0pW_sendMessage);
      break;
    }
    case 0xFDAB8735: { // 1507-time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ljlY3iJS_sendMessage);
      break;
    }
    case 0xDF8C2721: { // __hv_dpf_bpm
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_5hPuBfks_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_AyeLjaY0_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_DL3Y::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "High";
        info->hash = 0xC9CE7B11;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "High_Cross";
        info->hash = 0xBB584857;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 2: {
        info->name = "High_Feedback";
        info->hash = 0xACE44B9C;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 25.0f;
        break;
      }
      case 3: {
        info->name = "High_Mix";
        info->hash = 0xAC5FA57F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 4: {
        info->name = "High_Sync";
        info->hash = 0xDD62B09F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 5: {
        info->name = "High_Time";
        info->hash = 0xABB0CBCF;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 50.0f;
        info->maxVal = 5000.0f;
        info->defaultVal = 500.0f;
        break;
      }
      case 6: {
        info->name = "High_TimeSync";
        info->hash = 0xAE942A2;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 12.0f;
        info->defaultVal = 6.0f;
        break;
      }
      case 7: {
        info->name = "Low";
        info->hash = 0x87744544;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 8: {
        info->name = "Low_Cross";
        info->hash = 0xA2D68920;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 9: {
        info->name = "Low_Feedback";
        info->hash = 0xDDAB7A0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 25.0f;
        break;
      }
      case 10: {
        info->name = "Low_Mix";
        info->hash = 0x91FEF7A;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 11: {
        info->name = "Low_Sync";
        info->hash = 0xFFFEE96;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 12: {
        info->name = "Low_Time";
        info->hash = 0xA3BD8A20;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 50.0f;
        info->maxVal = 5000.0f;
        info->defaultVal = 500.0f;
        break;
      }
      case 13: {
        info->name = "Low_TimeSync";
        info->hash = 0x67F58CFB;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 12.0f;
        info->defaultVal = 6.0f;
        break;
      }
      case 14: {
        info->name = "Mid";
        info->hash = 0xBFDC48B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 15: {
        info->name = "Mid_Cross";
        info->hash = 0x59607D3;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 16: {
        info->name = "Mid_Feedback";
        info->hash = 0x9B44FA2D;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 25.0f;
        break;
      }
      case 17: {
        info->name = "Mid_Freq";
        info->hash = 0x59CF21AC;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 313.3f;
        info->maxVal = 5705.6f;
        info->defaultVal = 1337.0f;
        break;
      }
      case 18: {
        info->name = "Mid_Mix";
        info->hash = 0x676FE235;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 19: {
        info->name = "Mid_Sync";
        info->hash = 0x96E19510;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 20: {
        info->name = "Mid_Time";
        info->hash = 0xE1DB1774;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 50.0f;
        info->maxVal = 5000.0f;
        info->defaultVal = 500.0f;
        break;
      }
      case 21: {
        info->name = "Mid_TimeSync";
        info->hash = 0xDB67B94E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 12.0f;
        info->defaultVal = 6.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 22;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_DL3Y::cVar_vQXLxu8f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_v5QUUWCa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_SJM0ySRy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ykb7Y55d_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_cIej8H7r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tWqRnw4M_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_e7j6nn4t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1bxfKpTH_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_28qQXH6s_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QIO5OcrS_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_voXJTcbv_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_LdGS12Gw_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_XWpAxCo4, 0, m, &cSlice_XWpAxCo4_sendMessage);
      break;
    }
    default: {
      cSwitchcase_IxPFgX3C_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_XWpAxCo4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_kwWpKCMF_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_kwWpKCMF_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_RT1nkx3t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_kwWpKCMF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_kwWpKCMF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_oDG18UOJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_c8OfgimG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_gTKFKiJu_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_YfVeaCr8, 0, m, &cIf_YfVeaCr8_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_YfVeaCr8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_F2q1uPWZ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_GJo5lcsc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_XmmrQ1kJ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_q6NJ6gP6_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_AwiZr04b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_9sMrwzn0, HV_BINOP_POW, 0, m, &cBinop_9sMrwzn0_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9sMrwzn0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CRMRuevC, 0, m, &cIf_CRMRuevC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_4AB7PtjS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_BSP1UVIc_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_1laRTeK7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_GJo5lcsc, 0, m, &cIf_GJo5lcsc_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_tve2aw4Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_lSd1vGko_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_lSd1vGko_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_GJo5lcsc, 1, m, &cIf_GJo5lcsc_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_q6NJ6gP6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_4AB7PtjS_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_XmmrQ1kJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_CRMRuevC, 0, m, &cIf_CRMRuevC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_BSP1UVIc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9sMrwzn0, HV_BINOP_POW, 1, m, &cBinop_9sMrwzn0_sendMessage);
  cMsg_AwiZr04b_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_CRMRuevC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_4BUwEWtU, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_gTKFKiJu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YfVeaCr8, 1, m, &cIf_YfVeaCr8_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_F2q1uPWZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_o6lozz7e, HV_BINOP_GREATER_THAN, 1, m, &cBinop_o6lozz7e_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_8ehsHhwX, HV_BINOP_EQ, 1, m, &cBinop_8ehsHhwX_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_7uuV7pnv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_1WyX1zgS, HV_BINOP_ADD, 0, m, &cBinop_1WyX1zgS_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1WyX1zgS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tve2aw4Y_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1laRTeK7_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_o6lozz7e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CRMRuevC, 1, m, &cIf_CRMRuevC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8ehsHhwX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0Tgz82zL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_0Tgz82zL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_4BUwEWtU, m);
}

void Heavy_WSTD_DL3Y::cCast_EgEYB7ue_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1WyX1zgS, HV_BINOP_ADD, 1, m, &cBinop_1WyX1zgS_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_o6lozz7e, HV_BINOP_GREATER_THAN, 0, m, &cBinop_o6lozz7e_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_8ehsHhwX, HV_BINOP_EQ, 0, m, &cBinop_8ehsHhwX_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Fsl3tXuH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7uuV7pnv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_azF8C4R6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_c8OfgimG, 0, m, &cVar_c8OfgimG_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_uBb2kzOA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_yXtxhBLT_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_76eocPrP, 0, m, &cIf_76eocPrP_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_76eocPrP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_z283IA01_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_n6nCUc6w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_i0Zgc4VX_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_bGsrVQdB_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_tHi0DNMT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_7642dZmg, HV_BINOP_POW, 0, m, &cBinop_7642dZmg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_7642dZmg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_UfQmq1Wg, 0, m, &cIf_UfQmq1Wg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_dQwr0bV7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_dQuKAx3j_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_isHvvl7U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_n6nCUc6w, 0, m, &cIf_n6nCUc6w_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_fliVzGGH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_Eyet1fvT_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Eyet1fvT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_n6nCUc6w, 1, m, &cIf_n6nCUc6w_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_bGsrVQdB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_dQwr0bV7_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_i0Zgc4VX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_UfQmq1Wg, 0, m, &cIf_UfQmq1Wg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_dQuKAx3j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7642dZmg, HV_BINOP_POW, 1, m, &cBinop_7642dZmg_sendMessage);
  cMsg_tHi0DNMT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_UfQmq1Wg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_DKoOiZts_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_SrCQGaZg_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_9BM1WVE9_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_yXtxhBLT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_76eocPrP, 1, m, &cIf_76eocPrP_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_z283IA01_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Vl2gFRhl, HV_BINOP_GREATER_THAN, 1, m, &cBinop_Vl2gFRhl_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ChdDF13X, HV_BINOP_EQ, 1, m, &cBinop_ChdDF13X_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_YkZPiaJZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_DTqwU6UE, HV_BINOP_ADD, 0, m, &cBinop_DTqwU6UE_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_DTqwU6UE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fliVzGGH_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_isHvvl7U_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Vl2gFRhl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_UfQmq1Wg, 1, m, &cIf_UfQmq1Wg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ChdDF13X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lnDnpZY9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_lnDnpZY9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_DKoOiZts_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_SrCQGaZg_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_9BM1WVE9_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_qDgNIFlZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DTqwU6UE, HV_BINOP_ADD, 1, m, &cBinop_DTqwU6UE_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Vl2gFRhl, HV_BINOP_GREATER_THAN, 0, m, &cBinop_Vl2gFRhl_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ChdDF13X, HV_BINOP_EQ, 0, m, &cBinop_ChdDF13X_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_INcr5T44_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_uBb2kzOA, 0, m, &cVar_uBb2kzOA_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_iH6h6upI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YkZPiaJZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_hA9VnOW7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_WY8X1lG9_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_ISzTnc6M, 0, m, &cIf_ISzTnc6M_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_ISzTnc6M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_LOIOYi5V_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_RXa3VfIx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_kZi2chVM_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_OnzXK8Xz_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_bgdDyzb8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_5XGBi0ah, HV_BINOP_POW, 0, m, &cBinop_5XGBi0ah_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5XGBi0ah_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Hehf9QHZ, 0, m, &cIf_Hehf9QHZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_12AUgfwE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_AMc83zRq_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_JsLxK7Dc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_wQUzQCew_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_iVn9AwYh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RXa3VfIx, 0, m, &cIf_RXa3VfIx_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_wQUzQCew_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RXa3VfIx, 1, m, &cIf_RXa3VfIx_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_OnzXK8Xz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_12AUgfwE_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_kZi2chVM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_Hehf9QHZ, 0, m, &cIf_Hehf9QHZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_AMc83zRq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5XGBi0ah, HV_BINOP_POW, 1, m, &cBinop_5XGBi0ah_sendMessage);
  cMsg_bgdDyzb8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_Hehf9QHZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_cXX7VPBI, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_WY8X1lG9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ISzTnc6M, 1, m, &cIf_ISzTnc6M_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_LOIOYi5V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_V9OAvCfs, HV_BINOP_GREATER_THAN, 1, m, &cBinop_V9OAvCfs_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_RlGkiQZQ, HV_BINOP_EQ, 1, m, &cBinop_RlGkiQZQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Ho9AZblg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_OijbtuSl, HV_BINOP_ADD, 0, m, &cBinop_OijbtuSl_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_OijbtuSl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JsLxK7Dc_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iVn9AwYh_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_V9OAvCfs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Hehf9QHZ, 1, m, &cIf_Hehf9QHZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_RlGkiQZQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4RG6LoxE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_4RG6LoxE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_cXX7VPBI, m);
}

void Heavy_WSTD_DL3Y::cCast_rI8bZ8GR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ho9AZblg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_kq8ublOW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OijbtuSl, HV_BINOP_ADD, 1, m, &cBinop_OijbtuSl_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_V9OAvCfs, HV_BINOP_GREATER_THAN, 0, m, &cBinop_V9OAvCfs_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_RlGkiQZQ, HV_BINOP_EQ, 0, m, &cBinop_RlGkiQZQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_DZtp7xR4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_hA9VnOW7, 0, m, &cVar_hA9VnOW7_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_cg7vdtCw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_znI3yxIM, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cSwitchcase_oSP7S87N_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_3gehNZ1d, 0, m, &cSlice_3gehNZ1d_sendMessage);
      break;
    }
    default: {
      cSwitchcase_LzQOHixt_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_3gehNZ1d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_8x4uddPl_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_8x4uddPl_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_7nIZcxWA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_8x4uddPl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_8x4uddPl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_X4lm9zQV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_LzQOHixt_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_fEkxyRzM, 0, m, &cSlice_fEkxyRzM_sendMessage);
      break;
    }
    default: {
      cSwitchcase_LdGS12Gw_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_fEkxyRzM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_1h51Hb1P_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_1h51Hb1P_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_lTBlOzWF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_1h51Hb1P_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_1h51Hb1P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_EDOiQRq1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_IxPFgX3C_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_KD50BumP, 0, m, &cSlice_KD50BumP_sendMessage);
      break;
    }
    default: {
      cSwitchcase_NSU418Bn_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_KD50BumP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_5i8hddKR_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_5i8hddKR_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_73E1FTrW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_5i8hddKR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_5i8hddKR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_IfqCXE0v_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_NSU418Bn_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_mybj2V2A, 0, m, &cSlice_mybj2V2A_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_mybj2V2A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_q2buFYQ3_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_q2buFYQ3_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_jygwXD0R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_q2buFYQ3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_q2buFYQ3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_46GusISW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_FhUyXsS5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_kJh0SaDR, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_bdqUSiMS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3rZMlBZo, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_kFbVOr1c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_LJQWHNTj, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_YgWfrgkn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tGrr9cPb, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_gqsHYzMv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vXzyv70z, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_FsmqbMI9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_0KpVNyB0_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_0KpVNyB0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_luE7TrBg, HV_BINOP_DIVIDE, 1, m, &cBinop_luE7TrBg_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TdyVGk5p_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_MLO8fOkD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_uUYewy3H_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_0Mh0YO6Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_MLO8fOkD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_uUYewy3H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_luE7TrBg, HV_BINOP_DIVIDE, 0, m, &cBinop_luE7TrBg_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_TdyVGk5p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0Mh0YO6Z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_luE7TrBg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DXOSJutD, HV_BINOP_MULTIPLY, 1, m, &cBinop_DXOSJutD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_DXOSJutD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Peqpf7X2_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_W0gjQ1jA_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_e5KgSjck_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_QBBBpP2w_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_hKnM61fp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_GuY8IQNz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_bOF9ExcQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_4iFtLyXb_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_4iFtLyXb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DXOSJutD, HV_BINOP_MULTIPLY, 0, m, &cBinop_DXOSJutD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ZpAHmKLh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_xh6jtIRw_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_xh6jtIRw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sSGYzm7A_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_lQPgZDpV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ooXoCPJh, 1, m, &cVar_ooXoCPJh_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_ooXoCPJh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SSVjyZGn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_CCWSPHRd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_629klerW, HV_BINOP_MULTIPLY, 1, m, &cBinop_629klerW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_sSvR5uDI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_CCWSPHRd_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_IUSIiH7e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_Vv7dqsEH_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Vv7dqsEH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_I9FxRK59, HV_BINOP_MULTIPLY, 1, m, &cBinop_I9FxRK59_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_jtXNyJpC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6kCrFwQ6, HV_BINOP_MULTIPLY, 1, m, &cBinop_6kCrFwQ6_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_tdgkiLWI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_jtXNyJpC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_LGeRYrAD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZuwmQ9Yv, HV_BINOP_MULTIPLY, 1, m, &cBinop_ZuwmQ9Yv_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_3hS9kPRl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_QVAxPBUf_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_QVAxPBUf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_c4CudSzg, HV_BINOP_MULTIPLY, 1, m, &cBinop_c4CudSzg_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_IIfnvSIG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NhblG56E_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_bOF9ExcQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_u8seHZ9P_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_JvVbAp6R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_ZpAHmKLh_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Peqpf7X2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_e5KgSjck_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_W0gjQ1jA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_hKnM61fp_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_QBBBpP2w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_tNHcIIUM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_GuY8IQNz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_jXKP0n8t_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_Gd5mKbMa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_MwRny1Wn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_sSGYzm7A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_50r7renF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_50r7renF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mQ4si676, HV_BINOP_MULTIPLY, 1, m, &cBinop_mQ4si676_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_mQ4si676_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_TKlSj9Nj_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_TKlSj9Nj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Gd5mKbMa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_SSVjyZGn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_SF9ftgrO_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_SF9ftgrO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bW8aMq5U_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_G3WMzHz9_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DGARftb9_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7A1PbROs_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_h8GcBroT_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RNiioXfC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_629klerW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FhUyXsS5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_I9FxRK59_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bdqUSiMS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_6kCrFwQ6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kFbVOr1c_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_ZuwmQ9Yv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YgWfrgkn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_c4CudSzg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gqsHYzMv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_EmYyJzgu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JvVbAp6R, 1, m, &cVar_JvVbAp6R_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_1Rp4uNn3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_IIfnvSIG, 0, m, &cVar_IIfnvSIG_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_bW8aMq5U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_DL3Y::cCast_DGARftb9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZuwmQ9Yv, HV_BINOP_MULTIPLY, 0, m, &cBinop_ZuwmQ9Yv_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_h8GcBroT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_I9FxRK59, HV_BINOP_MULTIPLY, 0, m, &cBinop_I9FxRK59_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_7A1PbROs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6kCrFwQ6, HV_BINOP_MULTIPLY, 0, m, &cBinop_6kCrFwQ6_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_G3WMzHz9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_c4CudSzg, HV_BINOP_MULTIPLY, 0, m, &cBinop_c4CudSzg_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_RNiioXfC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_629klerW, HV_BINOP_MULTIPLY, 0, m, &cBinop_629klerW_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_u8seHZ9P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ooXoCPJh, 0, m, &cVar_ooXoCPJh_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_NhblG56E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JvVbAp6R, 0, m, &cVar_JvVbAp6R_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_CppRpbfs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7T7RPtZX, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_StnYCAJQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8Ibo082F, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_ryg2uW9w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_HD68qRAu, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_r6GsHqvJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2OdqylDk, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_s8uE0jg6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_HGkH1nTU_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_HGkH1nTU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ftex1NQH, HV_BINOP_DIVIDE, 1, m, &cBinop_Ftex1NQH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vZxoVWhV_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_L6CkZGb9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_KhGSV95o_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_h9e5ru9R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_L6CkZGb9_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_KhGSV95o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ftex1NQH, HV_BINOP_DIVIDE, 0, m, &cBinop_Ftex1NQH_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_vZxoVWhV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_h9e5ru9R_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Ftex1NQH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_y6a8tGuM, HV_BINOP_MULTIPLY, 1, m, &cBinop_y6a8tGuM_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_y6a8tGuM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_U11NMWc1_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ljnqQUeX_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_cot8QdCu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_nq2tw5Be_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_s7cAwy0T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_plcHz6yR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Hyai6JbZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_NXVHx8rg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_NXVHx8rg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_y6a8tGuM, HV_BINOP_MULTIPLY, 0, m, &cBinop_y6a8tGuM_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_rA7fva5l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_cW6It3Rn_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_cW6It3Rn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_K8bRSTww_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_TTcYRDP3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bYfshN5r, HV_BINOP_MULTIPLY, 1, m, &cBinop_bYfshN5r_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_U7M2BE2V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vtpl1cdB, 1, m, &cVar_vtpl1cdB_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_q0N4Up9V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ezAXfaar, HV_BINOP_MULTIPLY, 1, m, &cBinop_ezAXfaar_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_LdgywwMt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Vnw60SfJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Vnw60SfJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PUg5a1Lo, HV_BINOP_MULTIPLY, 1, m, &cBinop_PUg5a1Lo_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_vtpl1cdB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6mgt3OCY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_WVQT39BW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ntP6zUWj_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_Hyai6JbZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_P1sDMvI2_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_rvIbbYXm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_rA7fva5l_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_U11NMWc1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_cot8QdCu_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ljnqQUeX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_s7cAwy0T_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_nq2tw5Be_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_xEqPfHZu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_plcHz6yR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ooBu7uM3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_icMQi07W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_cg9zb3Hx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_K8bRSTww_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_4z0ceyr8_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_4z0ceyr8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_l9Ia4XUM, HV_BINOP_MULTIPLY, 1, m, &cBinop_l9Ia4XUM_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_l9Ia4XUM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_yUB0AOho_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_yUB0AOho_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_icMQi07W_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_6mgt3OCY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_ZCj4Xf2R_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ZCj4Xf2R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qZq9qaMe_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Zti3senC_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HnQDBWjN_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GEKr9e9k_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_RybKQ2hC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CppRpbfs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_bYfshN5r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_StnYCAJQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_ezAXfaar_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ryg2uW9w_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_PUg5a1Lo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_r6GsHqvJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_mkvw0qDw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WVQT39BW, 0, m, &cVar_WVQT39BW_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_pFTdp3D5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_rvIbbYXm, 1, m, &cVar_rvIbbYXm_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_P1sDMvI2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vtpl1cdB, 0, m, &cVar_vtpl1cdB_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ntP6zUWj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_rvIbbYXm, 0, m, &cVar_rvIbbYXm_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_HnQDBWjN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bYfshN5r, HV_BINOP_MULTIPLY, 0, m, &cBinop_bYfshN5r_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_GEKr9e9k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RybKQ2hC, HV_BINOP_MULTIPLY, 0, m, &cBinop_RybKQ2hC_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Zti3senC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ezAXfaar, HV_BINOP_MULTIPLY, 0, m, &cBinop_ezAXfaar_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_qZq9qaMe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PUg5a1Lo, HV_BINOP_MULTIPLY, 0, m, &cBinop_PUg5a1Lo_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_8gjY8CA9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_39iA6lvR, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_cE6RttpQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2OwiFIU4, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_k3LYi7y3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Hur7B5gv, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_KDiKv3Xi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_C5qy58mo, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_GchQaMHm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8PYhkDAo, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_X4nfG7LM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_dZXDoq71_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_dZXDoq71_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kLUulv6e, HV_BINOP_DIVIDE, 1, m, &cBinop_kLUulv6e_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yNDnR0pG_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_ZlR3wKos_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_J4tdIAIe_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_p09r8oUc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_ZlR3wKos_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_J4tdIAIe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kLUulv6e, HV_BINOP_DIVIDE, 0, m, &cBinop_kLUulv6e_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_yNDnR0pG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_p09r8oUc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_kLUulv6e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vvfaVJ7N, HV_BINOP_MULTIPLY, 1, m, &cBinop_vvfaVJ7N_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_vvfaVJ7N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5lMOUkQs_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_clqg0Ntt_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_hgkKEuty_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_cOWGxiTz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_DjpFlx2R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_xHE81lW9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_3UQeSd4z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_Z9vglbk5_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Z9vglbk5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vvfaVJ7N, HV_BINOP_MULTIPLY, 0, m, &cBinop_vvfaVJ7N_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_aF314sYi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_9S8UDEKM_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9S8UDEKM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Yy7LxLC3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_NneX0bbw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eB4ctzYN, HV_BINOP_MULTIPLY, 1, m, &cBinop_eB4ctzYN_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_iBKK1tII_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_bxVx0QKE_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_bxVx0QKE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_NneX0bbw_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_bbeHnZzb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_AqXCWV8W_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_AqXCWV8W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7EKdyZKD, HV_BINOP_MULTIPLY, 1, m, &cBinop_7EKdyZKD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_q0c4Yn1T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gMhXHIF6, HV_BINOP_MULTIPLY, 1, m, &cBinop_gMhXHIF6_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_yhk142DU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_kVq3JXow_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_kVq3JXow_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_q0c4Yn1T_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_SIbnxqkh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_W41grYbX, 1, m, &cVar_W41grYbX_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_j9Lc7ly7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eyEYNHlU, HV_BINOP_MULTIPLY, 1, m, &cBinop_eyEYNHlU_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_rsbl8KuO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_yz0Clt59_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_yz0Clt59_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_P61wr1HY, HV_BINOP_MULTIPLY, 1, m, &cBinop_P61wr1HY_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_W41grYbX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kiKmv7zB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_MxZQKyRp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RQNmtvvN_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_3UQeSd4z_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HuCauYhC_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_12gx9RtV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_aF314sYi_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_5lMOUkQs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_hgkKEuty_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_clqg0Ntt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_DjpFlx2R_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_cOWGxiTz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_1XUzBEvj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_xHE81lW9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_zZg6JXDR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_kiG79wju_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_9RfMaMjT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_Yy7LxLC3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_xYVo10zX_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_xYVo10zX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uo4MLQxX, HV_BINOP_MULTIPLY, 1, m, &cBinop_uo4MLQxX_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_uo4MLQxX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_rWtA8USg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_rWtA8USg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_kiG79wju_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_kiKmv7zB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_xZ0gKt0q_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_xZ0gKt0q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hgtNtaZH_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uR0zVdvH_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FjWmwwJq_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zceOtDug_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dnvq2LFO_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Ubuh0Q6g_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_eB4ctzYN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8gjY8CA9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_7EKdyZKD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cE6RttpQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_gMhXHIF6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_k3LYi7y3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_eyEYNHlU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KDiKv3Xi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_P61wr1HY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GchQaMHm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_jzFkmGSe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MxZQKyRp, 0, m, &cVar_MxZQKyRp_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_gEmCj1fE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_12gx9RtV, 1, m, &cVar_12gx9RtV_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_zceOtDug_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gMhXHIF6, HV_BINOP_MULTIPLY, 0, m, &cBinop_gMhXHIF6_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_uR0zVdvH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_P61wr1HY, HV_BINOP_MULTIPLY, 0, m, &cBinop_P61wr1HY_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_dnvq2LFO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7EKdyZKD, HV_BINOP_MULTIPLY, 0, m, &cBinop_7EKdyZKD_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Ubuh0Q6g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eB4ctzYN, HV_BINOP_MULTIPLY, 0, m, &cBinop_eB4ctzYN_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_FjWmwwJq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eyEYNHlU, HV_BINOP_MULTIPLY, 0, m, &cBinop_eyEYNHlU_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_hgtNtaZH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_DL3Y::cCast_RQNmtvvN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_12gx9RtV, 0, m, &cVar_12gx9RtV_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_HuCauYhC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_W41grYbX, 0, m, &cVar_W41grYbX_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_DKoOiZts_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_cg7vdtCw, 1, m, &cIf_cg7vdtCw_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_xKOVjcjh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_znI3yxIM, m);
}

void Heavy_WSTD_DL3Y::cBinop_SrCQGaZg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xKOVjcjh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_9BM1WVE9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_cg7vdtCw, 0, m, &cIf_cg7vdtCw_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_Yh4Z92MJ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_cYzdC61n, 0, m, &cSlice_cYzdC61n_sendMessage);
      break;
    }
    default: {
      cSwitchcase_4AMPJoZy_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_cYzdC61n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_zPpfgnYN_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_zPpfgnYN_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_gU9dF0aN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_zPpfgnYN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_zPpfgnYN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_MfzTaWKO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_Ixb8M9k4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_TYDX8bgJ_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_mVRzg57y, 0, m, &cIf_mVRzg57y_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_mVRzg57y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_Qdw7Ks9q_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_AicbegzZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_OTep5xMC_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_XY38YPN8_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_bafQLQGY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_jdBc9Hp5, HV_BINOP_POW, 0, m, &cBinop_jdBc9Hp5_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_jdBc9Hp5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_U3RC49xJ, 0, m, &cIf_U3RC49xJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_J5DAKFm8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_IkZt6hRo_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_0GtwlvO7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AicbegzZ, 0, m, &cIf_AicbegzZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_M2sW01zF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_EouQosry_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_EouQosry_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AicbegzZ, 1, m, &cIf_AicbegzZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_XY38YPN8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_J5DAKFm8_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_OTep5xMC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_U3RC49xJ, 0, m, &cIf_U3RC49xJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_IkZt6hRo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jdBc9Hp5, HV_BINOP_POW, 1, m, &cBinop_jdBc9Hp5_sendMessage);
  cMsg_bafQLQGY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_U3RC49xJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_kDmdw5sM, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_TYDX8bgJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_mVRzg57y, 1, m, &cIf_mVRzg57y_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Qdw7Ks9q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xbyHKnpl, HV_BINOP_GREATER_THAN, 1, m, &cBinop_xbyHKnpl_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_z3DRHios, HV_BINOP_EQ, 1, m, &cBinop_z3DRHios_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_X2G1YSxZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_gHX8x5BH, HV_BINOP_ADD, 0, m, &cBinop_gHX8x5BH_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_gHX8x5BH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_M2sW01zF_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0GtwlvO7_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_xbyHKnpl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_U3RC49xJ, 1, m, &cIf_U3RC49xJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_z3DRHios_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KP1XGgPX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_KP1XGgPX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_kDmdw5sM, m);
}

void Heavy_WSTD_DL3Y::cCast_riejjkrG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gHX8x5BH, HV_BINOP_ADD, 1, m, &cBinop_gHX8x5BH_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_xbyHKnpl, HV_BINOP_GREATER_THAN, 0, m, &cBinop_xbyHKnpl_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_z3DRHios, HV_BINOP_EQ, 0, m, &cBinop_z3DRHios_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_nZ330imf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Ixb8M9k4, 0, m, &cVar_Ixb8M9k4_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_cjjeMAhW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_X2G1YSxZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_4N3znSAu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_1JtL3WuB_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_LOcTIa3h, 0, m, &cIf_LOcTIa3h_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_LOcTIa3h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_hb1eRwC2_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_TNz4Nvfa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_pGz2EtBt_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_IOT6sCsy_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_uB6CIBfQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_3u9iMR0r, HV_BINOP_POW, 0, m, &cBinop_3u9iMR0r_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_3u9iMR0r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_eEaE3f6L, 0, m, &cIf_eEaE3f6L_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_V4SorNwo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_P2tTKVkB_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_E7d5Fcqs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_RC0YOuKI_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_cZgLuwA3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_TNz4Nvfa, 0, m, &cIf_TNz4Nvfa_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_RC0YOuKI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_TNz4Nvfa, 1, m, &cIf_TNz4Nvfa_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_IOT6sCsy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_V4SorNwo_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_pGz2EtBt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_eEaE3f6L, 0, m, &cIf_eEaE3f6L_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_P2tTKVkB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3u9iMR0r, HV_BINOP_POW, 1, m, &cBinop_3u9iMR0r_sendMessage);
  cMsg_uB6CIBfQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_eEaE3f6L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_o2D6U4Bx_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_H53IpnB9_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_Rj0U4HjF_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_1JtL3WuB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LOcTIa3h, 1, m, &cIf_LOcTIa3h_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_hb1eRwC2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_u1LlZxdD, HV_BINOP_GREATER_THAN, 1, m, &cBinop_u1LlZxdD_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_6dUv23f7, HV_BINOP_EQ, 1, m, &cBinop_6dUv23f7_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_BmL71NbN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_X5SrpjSJ, HV_BINOP_ADD, 0, m, &cBinop_X5SrpjSJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_X5SrpjSJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_E7d5Fcqs_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cZgLuwA3_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_u1LlZxdD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_eEaE3f6L, 1, m, &cIf_eEaE3f6L_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_6dUv23f7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MWc30WYg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_MWc30WYg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_o2D6U4Bx_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_H53IpnB9_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_Rj0U4HjF_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_AExKm5u9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4N3znSAu, 0, m, &cVar_4N3znSAu_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_JBTZse24_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_X5SrpjSJ, HV_BINOP_ADD, 1, m, &cBinop_X5SrpjSJ_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_u1LlZxdD, HV_BINOP_GREATER_THAN, 0, m, &cBinop_u1LlZxdD_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_6dUv23f7, HV_BINOP_EQ, 0, m, &cBinop_6dUv23f7_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_2A8W41FX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BmL71NbN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_yNeTV4qH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_AcRCnpR0_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_R9ZjHqyw, 0, m, &cIf_R9ZjHqyw_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_R9ZjHqyw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_aAVo5Owy_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_c5281j2s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_JaXs5kOD_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_Itds6XFn_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_UmtcTBJF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_tQ1MwGyp, HV_BINOP_POW, 0, m, &cBinop_tQ1MwGyp_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_tQ1MwGyp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kWzwAccD, 0, m, &cIf_kWzwAccD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_X8Zed8Vo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_U5syXOUT_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_N7GE7uwm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_c5281j2s, 0, m, &cIf_c5281j2s_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_VbtV5rIK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_FlvwMpoH_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_FlvwMpoH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_c5281j2s, 1, m, &cIf_c5281j2s_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Itds6XFn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_X8Zed8Vo_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_JaXs5kOD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_kWzwAccD, 0, m, &cIf_kWzwAccD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_U5syXOUT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tQ1MwGyp, HV_BINOP_POW, 1, m, &cBinop_tQ1MwGyp_sendMessage);
  cMsg_UmtcTBJF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_kWzwAccD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_d6xR9yDw, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_AcRCnpR0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_R9ZjHqyw, 1, m, &cIf_R9ZjHqyw_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_aAVo5Owy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_R32yFgy2, HV_BINOP_GREATER_THAN, 1, m, &cBinop_R32yFgy2_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_RbsDpD06, HV_BINOP_EQ, 1, m, &cBinop_RbsDpD06_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_u0CL5sAi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_b8iapbcE, HV_BINOP_ADD, 0, m, &cBinop_b8iapbcE_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_b8iapbcE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VbtV5rIK_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_N7GE7uwm_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_R32yFgy2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kWzwAccD, 1, m, &cIf_kWzwAccD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_RbsDpD06_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KkiR6hbx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_KkiR6hbx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_d6xR9yDw, m);
}

void Heavy_WSTD_DL3Y::cCast_YSIUQ1vr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_u0CL5sAi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_stEMDTxg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_b8iapbcE, HV_BINOP_ADD, 1, m, &cBinop_b8iapbcE_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_R32yFgy2, HV_BINOP_GREATER_THAN, 0, m, &cBinop_R32yFgy2_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_RbsDpD06, HV_BINOP_EQ, 0, m, &cBinop_RbsDpD06_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_YcMbejhA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_yNeTV4qH, 0, m, &cVar_yNeTV4qH_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_csVmJY7u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_aJqNvZb4, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cSwitchcase_GBbfKaHE_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_CkEn2SHD, 0, m, &cSlice_CkEn2SHD_sendMessage);
      break;
    }
    default: {
      cSwitchcase_4Wc7z6AC_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_CkEn2SHD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_gB0FgLrG_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_gB0FgLrG_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_HGn0lA2X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_gB0FgLrG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_gB0FgLrG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_qu6k4DPL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_4Wc7z6AC_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_n7MZwLFB, 0, m, &cSlice_n7MZwLFB_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Yh4Z92MJ_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_n7MZwLFB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_U9mRSkzj_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_U9mRSkzj_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_gOr7IVzh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_U9mRSkzj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_U9mRSkzj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_6pXvPuIA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_4AMPJoZy_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_NDTEJgpr, 0, m, &cSlice_NDTEJgpr_sendMessage);
      break;
    }
    default: {
      cSwitchcase_LdOItLYi_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_NDTEJgpr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_sIXXFUWi_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_sIXXFUWi_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_coZegqn7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_sIXXFUWi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_sIXXFUWi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_4YCSqKpW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_LdOItLYi_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_HO0jIDnf, 0, m, &cSlice_HO0jIDnf_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_HO0jIDnf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_dCcZUPCe_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_dCcZUPCe_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_rn2jMZab_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_dCcZUPCe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_dCcZUPCe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_WRVyVj5l_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_BcaO9jm0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_eXhDUNtk, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_8BCCMLpc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_D1JuR0s9, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_Rsy8jPlH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vwerc7LU, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_lRNaMKkF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_SOrwhjhI, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_MG0MEySu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1I0JV0CW, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_zGrzOAT1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_IfVtCFzH_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_IfVtCFzH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DNr4o6Ui, HV_BINOP_DIVIDE, 1, m, &cBinop_DNr4o6Ui_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wYczdEEP_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_FikjRBXb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_2vjjoqvM_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_UpvMIgy1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_FikjRBXb_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_2vjjoqvM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DNr4o6Ui, HV_BINOP_DIVIDE, 0, m, &cBinop_DNr4o6Ui_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_wYczdEEP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UpvMIgy1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_DNr4o6Ui_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lhSLtJOz, HV_BINOP_MULTIPLY, 1, m, &cBinop_lhSLtJOz_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_lhSLtJOz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4dgDP0mx_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IvMgR2Q9_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_jctq9aUq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_lhG9CZ10_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_9PTMPQIN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_kHJHU4Qa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_K4PntYeq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_nPomiJHY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_nPomiJHY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lhSLtJOz, HV_BINOP_MULTIPLY, 0, m, &cBinop_lhSLtJOz_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_GwBD9XdG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_MOBkd0j0_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_MOBkd0j0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RQ4rUMVE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_mEt0zIJC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_anS8ivGj, 1, m, &cVar_anS8ivGj_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_anS8ivGj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1h8gU5YE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_MBzFr0GJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_36C0tLaK, HV_BINOP_MULTIPLY, 1, m, &cBinop_36C0tLaK_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_GfsE6d2E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_MBzFr0GJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_e65MrBhl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_rqSEvFBF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_rqSEvFBF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ErAikW72, HV_BINOP_MULTIPLY, 1, m, &cBinop_ErAikW72_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_DWfvi6p1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SlpJtgtP, HV_BINOP_MULTIPLY, 1, m, &cBinop_SlpJtgtP_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1r9lM5qJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_DWfvi6p1_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_YYx8pa2J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8vo1JQ9S, HV_BINOP_MULTIPLY, 1, m, &cBinop_8vo1JQ9S_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_YLxxyLmB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_7CB2EBvF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_7CB2EBvF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Zw4k9hGL, HV_BINOP_MULTIPLY, 1, m, &cBinop_Zw4k9hGL_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_S4B3aV9u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7yNfHXyJ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_K4PntYeq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8w69KAxB_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_zeVfTzPK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_GwBD9XdG_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_IvMgR2Q9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_9PTMPQIN_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_4dgDP0mx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_jctq9aUq_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_lhG9CZ10_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_uoKpAINg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_kHJHU4Qa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_QOeucAqD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_JDpWqku7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_EHKMiKT8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_RQ4rUMVE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_RUDXSz34_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_RUDXSz34_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NK7R2OhK, HV_BINOP_MULTIPLY, 1, m, &cBinop_NK7R2OhK_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_NK7R2OhK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_JfIyqgC2_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JfIyqgC2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_JDpWqku7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_1h8gU5YE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_SLxiAYUj_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_SLxiAYUj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SNsyNebo_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Tj7oIszg_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_z0gWMStU_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MRCob6DE_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_l0IC7Guk_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UeXf09HS_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_36C0tLaK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BcaO9jm0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_ErAikW72_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8BCCMLpc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_SlpJtgtP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Rsy8jPlH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_8vo1JQ9S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lRNaMKkF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Zw4k9hGL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MG0MEySu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_r2yFhJvH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zeVfTzPK, 1, m, &cVar_zeVfTzPK_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ac1ShRCb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_S4B3aV9u, 0, m, &cVar_S4B3aV9u_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_z0gWMStU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8vo1JQ9S, HV_BINOP_MULTIPLY, 0, m, &cBinop_8vo1JQ9S_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_l0IC7Guk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ErAikW72, HV_BINOP_MULTIPLY, 0, m, &cBinop_ErAikW72_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Tj7oIszg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Zw4k9hGL, HV_BINOP_MULTIPLY, 0, m, &cBinop_Zw4k9hGL_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_MRCob6DE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SlpJtgtP, HV_BINOP_MULTIPLY, 0, m, &cBinop_SlpJtgtP_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_SNsyNebo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_DL3Y::cCast_UeXf09HS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_36C0tLaK, HV_BINOP_MULTIPLY, 0, m, &cBinop_36C0tLaK_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_7yNfHXyJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zeVfTzPK, 0, m, &cVar_zeVfTzPK_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_8w69KAxB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_anS8ivGj, 0, m, &cVar_anS8ivGj_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_EIbeVGE2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tMVolzDU, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_sZ09nVPY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_v3YC6iS3, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_cxnbHacJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_JciVd4YJ, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_03jjiQ6T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ReJFyme2, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_16b5XcWh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_DMY65rJj_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_DMY65rJj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1gfwFBW3, HV_BINOP_DIVIDE, 1, m, &cBinop_1gfwFBW3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Po2BprHo_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_VpohawnA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_vTnd8Zkq_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_hHApW1Eg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_VpohawnA_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_vTnd8Zkq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1gfwFBW3, HV_BINOP_DIVIDE, 0, m, &cBinop_1gfwFBW3_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Po2BprHo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hHApW1Eg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_1gfwFBW3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5vRZbH0t, HV_BINOP_MULTIPLY, 1, m, &cBinop_5vRZbH0t_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5vRZbH0t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_c2aKdBYc_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dxcFPyWT_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_8Pcw8xen_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_9NElRx7p_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_7i54QrC0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_rF5CVp6S_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_7s8wjGkn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_odYbe6fg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_odYbe6fg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5vRZbH0t, HV_BINOP_MULTIPLY, 0, m, &cBinop_5vRZbH0t_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_6IiTiNeB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_P1aqlYBX_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_P1aqlYBX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eYpMstp8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_r9KJKZ1e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bVnpWwVB, HV_BINOP_MULTIPLY, 1, m, &cBinop_bVnpWwVB_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_3l6riiQP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lGb1r5Be, 1, m, &cVar_lGb1r5Be_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_PWusEGHI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oo3nV6Bx, HV_BINOP_MULTIPLY, 1, m, &cBinop_oo3nV6Bx_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_jQyTDdwv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_7FWz6i85_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_7FWz6i85_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EulpuXcs, HV_BINOP_MULTIPLY, 1, m, &cBinop_EulpuXcs_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_lGb1r5Be_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iMa42t2e_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_XGikqTeD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hmSNNGi8_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_7s8wjGkn_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aWTT8scx_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_y7xLO2x2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_6IiTiNeB_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_c2aKdBYc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_8Pcw8xen_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_dxcFPyWT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_7i54QrC0_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_9NElRx7p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_si9cLD9G_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_rF5CVp6S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_3fJ0mtQN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_girDbaAR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_K83qHObA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_eYpMstp8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_L3KJPdzA_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_L3KJPdzA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_D6NXiTna, HV_BINOP_MULTIPLY, 1, m, &cBinop_D6NXiTna_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_D6NXiTna_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_u8Q3DRnb_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_u8Q3DRnb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_girDbaAR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_iMa42t2e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_NW13PX6R_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_NW13PX6R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_F2CF1Qnr_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_y3avdlpT_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jsNIEH0F_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7dta8MCL_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_4pHYAhc8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EIbeVGE2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_bVnpWwVB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sZ09nVPY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_oo3nV6Bx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cxnbHacJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_EulpuXcs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_03jjiQ6T_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_sh5ZFNGP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_XGikqTeD, 0, m, &cVar_XGikqTeD_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_EsrcEyAH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_y7xLO2x2, 1, m, &cVar_y7xLO2x2_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_hmSNNGi8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_y7xLO2x2, 0, m, &cVar_y7xLO2x2_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_aWTT8scx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lGb1r5Be, 0, m, &cVar_lGb1r5Be_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_7dta8MCL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4pHYAhc8, HV_BINOP_MULTIPLY, 0, m, &cBinop_4pHYAhc8_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_F2CF1Qnr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EulpuXcs, HV_BINOP_MULTIPLY, 0, m, &cBinop_EulpuXcs_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_jsNIEH0F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bVnpWwVB, HV_BINOP_MULTIPLY, 0, m, &cBinop_bVnpWwVB_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_y3avdlpT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oo3nV6Bx, HV_BINOP_MULTIPLY, 0, m, &cBinop_oo3nV6Bx_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_i8c2FFdU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_W71E820s, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_b2xuGV2o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_SKZfHngI, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_I7u4WpqC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7VUakwb1, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_zpSdeGK5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6J7Y9NNA, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_NN2ar7Yo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ZZ007Gc4, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_PL7Dqdeu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_G5k2Ebz4_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_G5k2Ebz4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1fm3ifgQ, HV_BINOP_DIVIDE, 1, m, &cBinop_1fm3ifgQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pNV2JGpP_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_RoOyEEq5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_xhTsVNQy_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_wEpEabMv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_RoOyEEq5_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_xhTsVNQy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1fm3ifgQ, HV_BINOP_DIVIDE, 0, m, &cBinop_1fm3ifgQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_pNV2JGpP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wEpEabMv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_1fm3ifgQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GDVOzYKC, HV_BINOP_MULTIPLY, 1, m, &cBinop_GDVOzYKC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_GDVOzYKC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9dVg0SYd_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tcLf6t4l_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_UFyG432q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_D7F6gv8c_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_3llIwSci_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_yR6B1s47_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_ftDTsr4P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_PqlIGoS9_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_PqlIGoS9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GDVOzYKC, HV_BINOP_MULTIPLY, 0, m, &cBinop_GDVOzYKC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_R6ZRfdcm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_lmVXpECJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_lmVXpECJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4WFM1KcF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_O6qCSEI9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XNjMHAA5, HV_BINOP_MULTIPLY, 1, m, &cBinop_XNjMHAA5_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_oWJw48PC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Qcvtw7dd_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Qcvtw7dd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_O6qCSEI9_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_xiN845zO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_DXELm6KG_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_DXELm6KG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5LRksFpp, HV_BINOP_MULTIPLY, 1, m, &cBinop_5LRksFpp_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_brvOcm1n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AsvU4Yxu, HV_BINOP_MULTIPLY, 1, m, &cBinop_AsvU4Yxu_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Xp7E7F23_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_k21ttBpy_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_k21ttBpy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_brvOcm1n_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_6ZCAAtKI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1slehZPC, 1, m, &cVar_1slehZPC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_0elq90yn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QHeij0FQ, HV_BINOP_MULTIPLY, 1, m, &cBinop_QHeij0FQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_uYFSnJCX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_PsvpPPzF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_PsvpPPzF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_h8BHd3GM, HV_BINOP_MULTIPLY, 1, m, &cBinop_h8BHd3GM_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_1slehZPC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6OWaPMMv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_2dt5mPi6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gCxAXPYJ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_ftDTsr4P_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MjZnHJif_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_m5Nb5vJp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_R6ZRfdcm_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_9dVg0SYd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_UFyG432q_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_tcLf6t4l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_3llIwSci_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_D7F6gv8c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_GXZFpwJq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_yR6B1s47_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_t3codlLV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_DYb6d0LM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_QUiVWvfz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_4WFM1KcF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_TBZltTQs_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_TBZltTQs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lheuA62s, HV_BINOP_MULTIPLY, 1, m, &cBinop_lheuA62s_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_lheuA62s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_QUH76rx1_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_QUH76rx1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_DYb6d0LM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_6OWaPMMv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_CJ6CnOhv_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_CJ6CnOhv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dVXsHyQH_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Tv5i9ju2_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_f3onFeh5_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vh2JSv5X_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZaJstysT_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sW5sHo0s_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_XNjMHAA5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_i8c2FFdU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_5LRksFpp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_b2xuGV2o_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_AsvU4Yxu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_I7u4WpqC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_QHeij0FQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zpSdeGK5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_h8BHd3GM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NN2ar7Yo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_f1I8JEH5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2dt5mPi6, 0, m, &cVar_2dt5mPi6_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_KcuJ3HJI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_m5Nb5vJp, 1, m, &cVar_m5Nb5vJp_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_dVXsHyQH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_DL3Y::cCast_f3onFeh5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QHeij0FQ, HV_BINOP_MULTIPLY, 0, m, &cBinop_QHeij0FQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_vh2JSv5X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AsvU4Yxu, HV_BINOP_MULTIPLY, 0, m, &cBinop_AsvU4Yxu_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Tv5i9ju2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_h8BHd3GM, HV_BINOP_MULTIPLY, 0, m, &cBinop_h8BHd3GM_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_sW5sHo0s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XNjMHAA5, HV_BINOP_MULTIPLY, 0, m, &cBinop_XNjMHAA5_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ZaJstysT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5LRksFpp, HV_BINOP_MULTIPLY, 0, m, &cBinop_5LRksFpp_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_gCxAXPYJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_m5Nb5vJp, 0, m, &cVar_m5Nb5vJp_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_MjZnHJif_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1slehZPC, 0, m, &cVar_1slehZPC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_o2D6U4Bx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_csVmJY7u, 1, m, &cIf_csVmJY7u_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_dgI3r2Zf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_aJqNvZb4, m);
}

void Heavy_WSTD_DL3Y::cBinop_H53IpnB9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dgI3r2Zf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Rj0U4HjF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_csVmJY7u, 0, m, &cIf_csVmJY7u_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_N4sNaUrM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gcJOyEwN, HV_BINOP_DIVIDE, 0, m, &cBinop_gcJOyEwN_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_nAp8jIWV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ddhNX5Wt, HV_BINOP_DIVIDE, 1, m, &cBinop_ddhNX5Wt_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_gcJOyEwN, HV_BINOP_DIVIDE, 1, m, &cBinop_gcJOyEwN_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_m7MagWix_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UwEYCdwA, HV_BINOP_DIVIDE, 0, m, &cBinop_UwEYCdwA_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_YnqZCgVI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UwEYCdwA, HV_BINOP_DIVIDE, 1, m, &cBinop_UwEYCdwA_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_QIO5OcrS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_N4sNaUrM, 0, m, &cVar_N4sNaUrM_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_28qQXH6s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_nAp8jIWV, 0, m, &cVar_nAp8jIWV_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_voXJTcbv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ddhNX5Wt, HV_BINOP_DIVIDE, 0, m, &cBinop_ddhNX5Wt_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ddhNX5Wt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_m7MagWix_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_gcJOyEwN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_YnqZCgVI_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_UwEYCdwA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_H1vzryHI_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_LW2mihzL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.313f, 0, m, &cBinop_18AqeEDF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_tWWfR7Qg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.313f, 0, m, &cBinop_1t9jCqhr_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_H1vzryHI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_tWWfR7Qg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1t9jCqhr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_LW2mihzL_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_18AqeEDF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uAlqv1P4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_4D84bAof_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GJySKLDk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_4xLNnZQa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mi4zUa3B_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_1fzLLmHs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_orYfVm0l_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_eGxjHHDh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SBTh4WwO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_89NvpIVT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QXTkNRmM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_2kMIXZHK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZCdabuEF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_Rh2uejpk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_G5coDW6G_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_ohIdpqxw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ow3KOD0A_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_57L0GOvH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JOpnzVoZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_boeOssgK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CB3RKang_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_xqeCbU0Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KjQQdMQY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_dYK79nh6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4n1FQ3JZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_OhoxtMkq_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_g9plPwMc, 0, m, &cSlice_g9plPwMc_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_g9plPwMc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_CahyHuNN_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_CahyHuNN_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_a1w8mscN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_CahyHuNN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_CahyHuNN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_egyAwq39_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_WH8vDZEu_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC8CCFEC1: { // "cross"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ffnmdhaZ, 0, m, &cSlice_ffnmdhaZ_sendMessage);
      break;
    }
    default: {
      cSwitchcase_i0R3Loze_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_ffnmdhaZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_usbC5fA0_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_usbC5fA0_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_Ijm8onJJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_usbC5fA0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_usbC5fA0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_8tzQf64h_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_khij03Mn_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x8E55AA5F: { // "time"
      cSlice_onMessage(_c, &Context(_c)->cSlice_1LcUvFYT, 0, m, &cSlice_1LcUvFYT_sendMessage);
      break;
    }
    default: {
      cSwitchcase_OhoxtMkq_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_1LcUvFYT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_WCQMupqb_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_WCQMupqb_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_5McP8Xud_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_WCQMupqb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_WCQMupqb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_91sk2V5X_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_rGpLx37j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_fqu6YkJh_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_fqu6YkJh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_Ogk5ihAB_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_TKI6iWs0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hY6BbadF_sendMessage(_c, 0, m);
  cMsg_WIem68ud_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_2CdTboUQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ipk3sejQ_sendMessage(_c, 0, m);
  cMsg_gOF9aWrL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Ogk5ihAB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_g1V2oIoJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_g1V2oIoJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hlzSgAmN_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Vl15D7IJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Vl15D7IJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Q8eqs2KE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_hlzSgAmN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_gUnQSIbl_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_gUnQSIbl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_LC5EQYIQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Q8eqs2KE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_qHJ5tnTX_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_qHJ5tnTX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_tmCg8o12_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_LC5EQYIQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_TKI6iWs0_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_tmCg8o12_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_2CdTboUQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_yfNEi0xX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_fPEDHFJx_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_fPEDHFJx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_04kRH14y_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_04kRH14y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_ertzxi6z_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ertzxi6z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Yv3Ksk7u_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_oSIa56rp_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_oSIa56rp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RtBH7gqx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_Yv3Ksk7u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_hSjsCQQH_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_hSjsCQQH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_6eHXNViL_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_RtBH7gqx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_cZ54NXod_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_cZ54NXod_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_gvrv1za2_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_gvrv1za2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_q1IZKf7D_sendMessage(_c, 0, m);
  cMsg_xwJIfnNW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_6eHXNViL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dd0IHPtX_sendMessage(_c, 0, m);
  cMsg_LBjhgCYg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_xQtzTdE0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_Mkt32J29_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Mkt32J29_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_zp5irSfD_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_6yevw3tu_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_5MV5sneD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_oB4zQoIW_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_nbeYmglS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Nj6DQbHZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_Nj6DQbHZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DeVtGCsC, HV_BINOP_DIVIDE, 1, m, &cBinop_DeVtGCsC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_zp5irSfD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_dYdyjA1Z_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_dYdyjA1Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_q9rV8ZfT, m);
}

void Heavy_WSTD_DL3Y::cMsg_dBLnVtf7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_uHHUINBO_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_uHHUINBO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_xQtzTdE0_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_6yevw3tu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_2WmMyujj, m);
}

void Heavy_WSTD_DL3Y::cBinop_oB4zQoIW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_GiTrsA8i_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_GiTrsA8i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DeVtGCsC, HV_BINOP_DIVIDE, 0, m, &cBinop_DeVtGCsC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_DeVtGCsC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dBLnVtf7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_hPaImZd6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_q04DxcSb_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_q04DxcSb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_0ljgv0Eb_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_QQTOvffM_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_xVdqLggW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_tkW2g8HL_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_lpDxvIq0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Xu03WIvj_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_Xu03WIvj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zcwFxg05, HV_BINOP_DIVIDE, 1, m, &cBinop_zcwFxg05_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_0ljgv0Eb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Atl8oNFe_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Atl8oNFe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_xQhBofaa, m);
}

void Heavy_WSTD_DL3Y::cMsg_Mq9dWIZl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_ySfeB20L_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ySfeB20L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_hPaImZd6_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_QQTOvffM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_GOw4Ag0B, m);
}

void Heavy_WSTD_DL3Y::cBinop_tkW2g8HL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_rhxzhyCi_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_rhxzhyCi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zcwFxg05, HV_BINOP_DIVIDE, 0, m, &cBinop_zcwFxg05_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_zcwFxg05_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Mq9dWIZl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_ayHvAT7o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0fqpKSek, HV_BINOP_MULTIPLY, 0, m, &cBinop_0fqpKSek_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_GC3z2zml_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_5DelKXxs_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_5DelKXxs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QqHpM5Z9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_0fqpKSek_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_7Y2OEqqy_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_B7vntwsG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0fqpKSek, HV_BINOP_MULTIPLY, 1, m, &cBinop_0fqpKSek_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_QqHpM5Z9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_B7vntwsG_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_7Y2OEqqy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_SPlEMDPi_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_SPlEMDPi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_RzZ9UCir_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_GGZvI91M, m);
}

void Heavy_WSTD_DL3Y::cBinop_RzZ9UCir_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_ybxY8DX1, m);
}

void Heavy_WSTD_DL3Y::cVar_fJRcAHjS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0UGBiQ3u, HV_BINOP_MULTIPLY, 0, m, &cBinop_0UGBiQ3u_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_LmKFzBHq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_YZa0ujUW_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_YZa0ujUW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Jcb5RK1Q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_0UGBiQ3u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_F7vuA2hO_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_hc9ifJYP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0UGBiQ3u, HV_BINOP_MULTIPLY, 1, m, &cBinop_0UGBiQ3u_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Jcb5RK1Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_hc9ifJYP_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_F7vuA2hO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_hyraWcfW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_hyraWcfW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_FO0pCttX_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_oWhjsW4v, m);
}

void Heavy_WSTD_DL3Y::cBinop_FO0pCttX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_XZgxXwpV, m);
}

void Heavy_WSTD_DL3Y::sEnv_G3Y4FPrS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4aDHpvJ4_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LUaRUpYx_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_O17I0DjY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_3WLmxXik_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_bwzfy2Ee_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_d9kj51sM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ghbeG9ck, HV_BINOP_POW, 0, m, &cBinop_ghbeG9ck_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ghbeG9ck_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rYKWxX87_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_u7Rl2AxX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_5jibUZ1c_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_4aDHpvJ4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_AyNXbh4k_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_LUaRUpYx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_O17I0DjY, 0, m, &cIf_O17I0DjY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_AyNXbh4k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_O17I0DjY, 1, m, &cIf_O17I0DjY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_bwzfy2Ee_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_u7Rl2AxX_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_3WLmxXik_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_rYKWxX87_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_5jibUZ1c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ghbeG9ck, HV_BINOP_POW, 1, m, &cBinop_ghbeG9ck_sendMessage);
  cMsg_d9kj51sM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_JQ0GI58W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GOWhVNMk, HV_BINOP_MULTIPLY, 0, m, &cBinop_GOWhVNMk_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_FfSLoJ0l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_BMxgUIjZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_BMxgUIjZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fcqVMAft_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_GOWhVNMk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_BGcuvHGE_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_zt21r3I1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GOWhVNMk, HV_BINOP_MULTIPLY, 1, m, &cBinop_GOWhVNMk_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_fcqVMAft_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_zt21r3I1_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_BGcuvHGE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_DJ0Ls8Xs_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_DJ0Ls8Xs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_pAXZk0cr_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_PufPqmnj, m);
}

void Heavy_WSTD_DL3Y::cBinop_pAXZk0cr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_UPTvDAyt, m);
}

void Heavy_WSTD_DL3Y::cMsg_rYKWxX87_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_pysK32ic_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_pysK32ic_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_6QUsvZ3b, m);
}

void Heavy_WSTD_DL3Y::sEnv_DusZaa7A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_j18XNLB0_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_U5OKRfDt_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_KAAN4WWh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_oLtFhmyE_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_1FTjv6sx_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_cgHSkDjG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_gWFoOmHd, HV_BINOP_POW, 0, m, &cBinop_gWFoOmHd_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_gWFoOmHd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ggkAiiCF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_pKSshDbr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_8GXjIcsD_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_j18XNLB0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_AuTABBGJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_U5OKRfDt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_KAAN4WWh, 0, m, &cIf_KAAN4WWh_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_AuTABBGJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_KAAN4WWh, 1, m, &cIf_KAAN4WWh_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1FTjv6sx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_pKSshDbr_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_oLtFhmyE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_ggkAiiCF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_8GXjIcsD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gWFoOmHd, HV_BINOP_POW, 1, m, &cBinop_gWFoOmHd_sendMessage);
  cMsg_cgHSkDjG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_tRIBZwXh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VB5f24yr, HV_BINOP_MULTIPLY, 0, m, &cBinop_VB5f24yr_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_PEcgrQZr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_djEY6OPq_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_djEY6OPq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_43FLJUFX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_VB5f24yr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_4698OhlE_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_4YTP3Glf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VB5f24yr, HV_BINOP_MULTIPLY, 1, m, &cBinop_VB5f24yr_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_43FLJUFX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_4YTP3Glf_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_4698OhlE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_n17t3zGU_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_n17t3zGU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_mdtTIpnM_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_p3X47L0v, m);
}

void Heavy_WSTD_DL3Y::cBinop_mdtTIpnM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_RBN38R9K, m);
}

void Heavy_WSTD_DL3Y::cMsg_ggkAiiCF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_urHI62tg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_urHI62tg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_ncBUKKHR, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_i0R3Loze_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_U2EMZAPS, 0, m, &cSlice_U2EMZAPS_sendMessage);
      break;
    }
    default: {
      cSwitchcase_khij03Mn_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_U2EMZAPS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_x43lA2Eh_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_x43lA2Eh_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_9e2Rbmrf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_x43lA2Eh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_x43lA2Eh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_1VNiKn07_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_zb7Y2hgo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ieJbgxpg_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_ieJbgxpg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_kujdU51W_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_SRYDGyav_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_SRYDGyav, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_xAgVxOv9, 0, m, &cDelay_xAgVxOv9_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_SRYDGyav, 0, m, &cDelay_SRYDGyav_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_bl2DJOVj, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_xAgVxOv9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_xAgVxOv9, m);
  cMsg_Fjv4VQIn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_qWGzbkeL_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_aGay6VH5_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_hZsfM8yA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9MhEon6P_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_2yjteFNY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qgbI6vfK_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_SRYDGyav, 2, m, &cDelay_SRYDGyav_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_t0AhNzdY_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_9MhEon6P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_2yjteFNY, 0, m, &hTable_2yjteFNY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_kujdU51W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_hZsfM8yA_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Fjv4VQIn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_2yjteFNY, 0, m, &hTable_2yjteFNY_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_t0AhNzdY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_SRYDGyav, 0, m, &cDelay_SRYDGyav_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_qgbI6vfK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_xAgVxOv9, 2, m, &cDelay_xAgVxOv9_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_aGay6VH5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_bl2DJOVj, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_qoIw022e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8DEkgxCV, HV_BINOP_SUBTRACT, 0, m, &cBinop_8DEkgxCV_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_BpGQWXar_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ZE9S5iJi_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_ZE9S5iJi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_ALQJcQVR_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_3ShYUhrc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pSfx76fU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_CwiapWJc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_CwiapWJc, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_9rafBBVp, 0, m, &cDelay_9rafBBVp_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_jCyYXfUp, 0, m, &sTabread_jCyYXfUp_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_9rafBBVp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_9rafBBVp, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_jCyYXfUp, 0, m, &sTabread_jCyYXfUp_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_9rafBBVp, 0, m, &cDelay_9rafBBVp_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_jCyYXfUp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_2Re6EYdM, HV_BINOP_SUBTRACT, 0, m, &cBinop_2Re6EYdM_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_Fk4KiUhD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MPXE6VMe, HV_BINOP_MAX, 0, m, &cBinop_MPXE6VMe_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ALQJcQVR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Fk4KiUhD, HV_BINOP_MULTIPLY, 0, m, &cBinop_Fk4KiUhD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8DEkgxCV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SA7EJCFJ_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_jCyYXfUp, 0, m, &sTabread_jCyYXfUp_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_m3Fs58Qv_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_cGQqqnak_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2Re6EYdM, HV_BINOP_SUBTRACT, 1, m, &cBinop_2Re6EYdM_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_9rafBBVp, 2, m, &cDelay_9rafBBVp_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_pSfx76fU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_cGQqqnak_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_SA7EJCFJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_CwiapWJc, 0, m, &cDelay_CwiapWJc_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_9rafBBVp, 0, m, &cDelay_9rafBBVp_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_wfEgFuYO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_MPXE6VMe, HV_BINOP_MAX, 1, m, &cBinop_MPXE6VMe_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_MPXE6VMe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8DEkgxCV, HV_BINOP_SUBTRACT, 1, m, &cBinop_8DEkgxCV_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_m3Fs58Qv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_CwiapWJc, 0, m, &cDelay_CwiapWJc_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_GJ1aJbWY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_CwiapWJc, 2, m, &cDelay_CwiapWJc_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_2Re6EYdM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_GJ1aJbWY_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_J7gCK2I1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3ShYUhrc, 0, m, &cVar_3ShYUhrc_sendMessage);
  cMsg_BpGQWXar_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_qoIw022e, 0, m, &cTabhead_qoIw022e_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_KSkO4m1S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_wTM33gmd_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_wTM33gmd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_XrTzp7hr_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_cZXt7FX8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_cZXt7FX8, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_o2seiopm, 0, m, &cDelay_o2seiopm_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_cZXt7FX8, 0, m, &cDelay_cZXt7FX8_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_4yWDat1p, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_o2seiopm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_o2seiopm, m);
  cMsg_bQONZYuc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_D3CmRxVQ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_EMFV82Mu_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_llr8zvoE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JhtZIs08_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_DbibR2UO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ctBWD4In_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_cZXt7FX8, 2, m, &cDelay_cZXt7FX8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rtdYnRNn_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_JhtZIs08_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_DbibR2UO, 0, m, &hTable_DbibR2UO_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_XrTzp7hr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_llr8zvoE_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_bQONZYuc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_DbibR2UO, 0, m, &hTable_DbibR2UO_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_rtdYnRNn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_cZXt7FX8, 0, m, &cDelay_cZXt7FX8_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ctBWD4In_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_o2seiopm, 2, m, &cDelay_o2seiopm_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_EMFV82Mu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_4yWDat1p, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_ofqcEpTF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dJGUUWNq, HV_BINOP_SUBTRACT, 0, m, &cBinop_dJGUUWNq_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_uLUjw0l1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_AKTfh1xk_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_AKTfh1xk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_ilS8FArN_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_YxyQ7ffb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yRlVhHpu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_iQ5GNxQJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_iQ5GNxQJ, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_VXoKzm8q, 0, m, &cDelay_VXoKzm8q_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_gumrO5pJ, 0, m, &sTabread_gumrO5pJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_VXoKzm8q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_VXoKzm8q, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_gumrO5pJ, 0, m, &sTabread_gumrO5pJ_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_VXoKzm8q, 0, m, &cDelay_VXoKzm8q_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_gumrO5pJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_ZYnOdmJK, HV_BINOP_SUBTRACT, 0, m, &cBinop_ZYnOdmJK_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_P9SSFtGk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_D844c03i, HV_BINOP_MAX, 0, m, &cBinop_D844c03i_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ilS8FArN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_P9SSFtGk, HV_BINOP_MULTIPLY, 0, m, &cBinop_P9SSFtGk_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_dJGUUWNq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3dcU7Ugu_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_gumrO5pJ, 0, m, &sTabread_gumrO5pJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fc4lLcfu_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_68DCDG5f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZYnOdmJK, HV_BINOP_SUBTRACT, 1, m, &cBinop_ZYnOdmJK_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_VXoKzm8q, 2, m, &cDelay_VXoKzm8q_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_yRlVhHpu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_68DCDG5f_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_3dcU7Ugu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_iQ5GNxQJ, 0, m, &cDelay_iQ5GNxQJ_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_VXoKzm8q, 0, m, &cDelay_VXoKzm8q_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_m9DZW5TX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_D844c03i, HV_BINOP_MAX, 1, m, &cBinop_D844c03i_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_D844c03i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dJGUUWNq, HV_BINOP_SUBTRACT, 1, m, &cBinop_dJGUUWNq_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_fc4lLcfu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_iQ5GNxQJ, 0, m, &cDelay_iQ5GNxQJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_21VZps1S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_iQ5GNxQJ, 2, m, &cDelay_iQ5GNxQJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ZYnOdmJK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_21VZps1S_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_02S9jfs6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_YxyQ7ffb, 0, m, &cVar_YxyQ7ffb_sendMessage);
  cMsg_uLUjw0l1_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_ofqcEpTF, 0, m, &cTabhead_ofqcEpTF_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_hY6BbadF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_wxptlJJc, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_Ipk3sejQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_QUo1G4gS, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_gOF9aWrL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_JB0Xe7Ux, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_WIem68ud_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_U9Cfb8gy, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_LBjhgCYg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_yENWJgcS, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_q1IZKf7D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_gKmidHOR, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_dd0IHPtX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Smhz4MkN, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_xwJIfnNW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_TptN4Ux4, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cSwitchcase_oGyq9QiY_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_olchhRzN, 0, m, &cSlice_olchhRzN_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_olchhRzN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_2QqSdFqb_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_2QqSdFqb_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_7ZmVbcnL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_2QqSdFqb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_2QqSdFqb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_6aXlfFpa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_Sb3Roju7_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC8CCFEC1: { // "cross"
      cSlice_onMessage(_c, &Context(_c)->cSlice_DXi8Hb5t, 0, m, &cSlice_DXi8Hb5t_sendMessage);
      break;
    }
    default: {
      cSwitchcase_WoYtZTJv_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_DXi8Hb5t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_jSiHh6Sf_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_jSiHh6Sf_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_n07xxocL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_jSiHh6Sf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_jSiHh6Sf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_WDa7pQAv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_AHtdwWab_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x8E55AA5F: { // "time"
      cSlice_onMessage(_c, &Context(_c)->cSlice_TYZ40Pi2, 0, m, &cSlice_TYZ40Pi2_sendMessage);
      break;
    }
    default: {
      cSwitchcase_oGyq9QiY_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_TYZ40Pi2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Q8r8Tv0Y_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Q8r8Tv0Y_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_w1bg2pdl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Q8r8Tv0Y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_Q8r8Tv0Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_wPbN32hU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_IpyPBIuW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_7BciDlKm_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_7BciDlKm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_trrajGBe_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_1Ga3epzQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iYaf9Axt_sendMessage(_c, 0, m);
  cMsg_6GASHk4k_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_kMJtsPqX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GrBBkgHn_sendMessage(_c, 0, m);
  cMsg_oNOUNJr6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_trrajGBe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_lDJ7WxCl_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_lDJ7WxCl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KgpVSJAx_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nogmbJlO_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_KgpVSJAx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_BlGtLlxH_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_nogmbJlO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TT56TDLI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_BlGtLlxH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_yN9xbURh_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_TT56TDLI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_T21BAFzr_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_T21BAFzr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_yOVuEjSL_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_yN9xbURh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_1Ga3epzQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_yOVuEjSL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_kMJtsPqX_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_KBawkOqd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_y4Xji7rN_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_y4Xji7rN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_kcBoZ6vc_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_kcBoZ6vc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_lATD564C_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_lATD564C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bnayCkXk_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wlNm6PWq_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_bnayCkXk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_zuyBT3FY_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_wlNm6PWq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Yk4KClSd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_zuyBT3FY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_oWlcHMlJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Yk4KClSd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_aKWiQPlD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_aKWiQPlD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Oajybw2y_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Oajybw2y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dQDw4PsS_sendMessage(_c, 0, m);
  cMsg_qxXSg4Id_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_oWlcHMlJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_L6s0GaTA_sendMessage(_c, 0, m);
  cMsg_SWKnmyL5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_98lgBvFa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_8D1Esq38_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8D1Esq38_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_tNKM4TP4_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_WsbTnKW4_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_VCun9Kn1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_S0ve41kS_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_h8VIossZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_uBBiAv0D_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_uBBiAv0D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_E8okldAt, HV_BINOP_DIVIDE, 1, m, &cBinop_E8okldAt_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_tNKM4TP4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_WQEjo0Fp_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_WQEjo0Fp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_0JFkmAVK, m);
}

void Heavy_WSTD_DL3Y::cMsg_tfCEZy5p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_6GBo6uxS_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_6GBo6uxS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_98lgBvFa_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_WsbTnKW4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_dfD9NjQc, m);
}

void Heavy_WSTD_DL3Y::cBinop_S0ve41kS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_htbCeBf0_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_htbCeBf0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_E8okldAt, HV_BINOP_DIVIDE, 0, m, &cBinop_E8okldAt_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_E8okldAt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tfCEZy5p_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_AnZVyXUF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_GQA6HZc9_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_GQA6HZc9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_ehj8U0dt_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_PyuEjB6u_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_LY4gasBz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_2GtuvPTT_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_uqwNpXXA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_PLoRd3Vv_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_PLoRd3Vv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lvHg3VUW, HV_BINOP_DIVIDE, 1, m, &cBinop_lvHg3VUW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ehj8U0dt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_1Vl9WY8E_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1Vl9WY8E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Sor2xfXa, m);
}

void Heavy_WSTD_DL3Y::cMsg_UmXHzlDi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_ZMGwRCTf_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ZMGwRCTf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_AnZVyXUF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_PyuEjB6u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_ES8wOcWX, m);
}

void Heavy_WSTD_DL3Y::cBinop_2GtuvPTT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_DvyCX8Gv_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_DvyCX8Gv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lvHg3VUW, HV_BINOP_DIVIDE, 0, m, &cBinop_lvHg3VUW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_lvHg3VUW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UmXHzlDi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_YWFkZvpr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_C6ILaBMj, HV_BINOP_MULTIPLY, 0, m, &cBinop_C6ILaBMj_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_tZIrcO9x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_21hAHHnd_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_21hAHHnd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ulWkJeMg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_C6ILaBMj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_b3uVVnZ8_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_KhGnW5uZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_C6ILaBMj, HV_BINOP_MULTIPLY, 1, m, &cBinop_C6ILaBMj_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ulWkJeMg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_KhGnW5uZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_b3uVVnZ8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_vdslTUQv_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_vdslTUQv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_ZcPg1Vuh_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_dvSTIikI, m);
}

void Heavy_WSTD_DL3Y::cBinop_ZcPg1Vuh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_e3gGVxVd, m);
}

void Heavy_WSTD_DL3Y::cVar_Vdjluy0T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IeugtuA0, HV_BINOP_MULTIPLY, 0, m, &cBinop_IeugtuA0_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_xY3Z7T50_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_osdsxjdc_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_osdsxjdc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9tyJoSJw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_IeugtuA0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_uPSMjQ0w_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_zmnSuAri_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IeugtuA0, HV_BINOP_MULTIPLY, 1, m, &cBinop_IeugtuA0_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_9tyJoSJw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_zmnSuAri_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_uPSMjQ0w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_FLGDRzSX_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_FLGDRzSX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_aHDaDh1R_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_Q2WXAtNx, m);
}

void Heavy_WSTD_DL3Y::cBinop_aHDaDh1R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_VAdL1307, m);
}

void Heavy_WSTD_DL3Y::sEnv_xvFSZtWZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sA0BkJIt_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_y7QKqGSl_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_oXcl5e9D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_dKPpOdTh_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_THyjtBbx_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_16Z1eEtL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_tRDSX8gU, HV_BINOP_POW, 0, m, &cBinop_tRDSX8gU_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_tRDSX8gU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QwTMqVc8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_2zjL7wWS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_XJfivEJj_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_y7QKqGSl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oXcl5e9D, 0, m, &cIf_oXcl5e9D_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_sA0BkJIt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_KxwUj6zd_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_KxwUj6zd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oXcl5e9D, 1, m, &cIf_oXcl5e9D_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_THyjtBbx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_2zjL7wWS_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_dKPpOdTh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_QwTMqVc8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_XJfivEJj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tRDSX8gU, HV_BINOP_POW, 1, m, &cBinop_tRDSX8gU_sendMessage);
  cMsg_16Z1eEtL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_UHcTmef7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vn9oV0AM, HV_BINOP_MULTIPLY, 0, m, &cBinop_vn9oV0AM_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_0oF1d4ps_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_bDdHA1k4_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_bDdHA1k4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JhOAyLni_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_vn9oV0AM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_Txc8rly9_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JXBQMSwo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vn9oV0AM, HV_BINOP_MULTIPLY, 1, m, &cBinop_vn9oV0AM_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_JhOAyLni_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_JXBQMSwo_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Txc8rly9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_V9CmFbLJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_V9CmFbLJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_LCpvcxcV_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_XzGRbfNn, m);
}

void Heavy_WSTD_DL3Y::cBinop_LCpvcxcV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_U4O6tKli, m);
}

void Heavy_WSTD_DL3Y::cMsg_QwTMqVc8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_oX9TBr2G_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_oX9TBr2G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_c2ai5P5T, m);
}

void Heavy_WSTD_DL3Y::sEnv_cj5rytmK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_H82XveKR_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bpb0wjj3_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_0I3HwFIb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_vlMcSR4Z_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_9AUssTaz_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_Vxgji7Zr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_T7s5f5xD, HV_BINOP_POW, 0, m, &cBinop_T7s5f5xD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_T7s5f5xD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WzJTsGVc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_pYxqyWaf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_CRPC48Uz_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_H82XveKR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_BrObEOi2_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_bpb0wjj3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0I3HwFIb, 0, m, &cIf_0I3HwFIb_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_BrObEOi2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0I3HwFIb, 1, m, &cIf_0I3HwFIb_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9AUssTaz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_pYxqyWaf_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_vlMcSR4Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_WzJTsGVc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_CRPC48Uz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_T7s5f5xD, HV_BINOP_POW, 1, m, &cBinop_T7s5f5xD_sendMessage);
  cMsg_Vxgji7Zr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_abNhgbxk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Zw8D6nCM, HV_BINOP_MULTIPLY, 0, m, &cBinop_Zw8D6nCM_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_8ihG5qwO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_LqBaqJQ8_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_LqBaqJQ8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ln7Czldk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Zw8D6nCM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_a3oIMMJB_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_uYWkJmML_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Zw8D6nCM, HV_BINOP_MULTIPLY, 1, m, &cBinop_Zw8D6nCM_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Ln7Czldk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_uYWkJmML_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_a3oIMMJB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_w8wtzmLb_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_w8wtzmLb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_jO075xBO_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_9Dn7f0SQ, m);
}

void Heavy_WSTD_DL3Y::cBinop_jO075xBO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_sGj9JT6t, m);
}

void Heavy_WSTD_DL3Y::cMsg_WzJTsGVc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_5FRh9nV7_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5FRh9nV7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_CKLGQAB3, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_WoYtZTJv_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_v6uyKJIG, 0, m, &cSlice_v6uyKJIG_sendMessage);
      break;
    }
    default: {
      cSwitchcase_AHtdwWab_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_v6uyKJIG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_F6t4CXjN_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_F6t4CXjN_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_tCuMRKRD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_F6t4CXjN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_F6t4CXjN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_38OO88lJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_kITeRI81_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_arGegWG7_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_arGegWG7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_uZpjMbop_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_rDOgMrQO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_rDOgMrQO, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_fGsUJrvY, 0, m, &cDelay_fGsUJrvY_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_rDOgMrQO, 0, m, &cDelay_rDOgMrQO_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_ss27HoFU, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_fGsUJrvY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_fGsUJrvY, m);
  cMsg_VoWARdMJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_2mFB3bSs_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_T81QrSEu_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_TQx0eDWr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Qjz2LUWJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_O5bUfp1K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OxBJX6EW_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_rDOgMrQO, 2, m, &cDelay_rDOgMrQO_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Qmuu4mRQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Qjz2LUWJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_O5bUfp1K, 0, m, &hTable_O5bUfp1K_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_uZpjMbop_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_TQx0eDWr_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_VoWARdMJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_O5bUfp1K, 0, m, &hTable_O5bUfp1K_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Qmuu4mRQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_rDOgMrQO, 0, m, &cDelay_rDOgMrQO_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_OxBJX6EW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_fGsUJrvY, 2, m, &cDelay_fGsUJrvY_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_T81QrSEu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_ss27HoFU, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_73d4VvaX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KhKnbVFP, HV_BINOP_SUBTRACT, 0, m, &cBinop_KhKnbVFP_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_07fheukR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Q8JEk7RO_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_Q8JEk7RO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_tAMeuVlz_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_lqM360pS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5yM49Fze_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_bhecObMw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_bhecObMw, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_tEuSutET, 0, m, &cDelay_tEuSutET_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_x2U2t9Yg, 0, m, &sTabread_x2U2t9Yg_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_tEuSutET_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_tEuSutET, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_x2U2t9Yg, 0, m, &sTabread_x2U2t9Yg_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_tEuSutET, 0, m, &cDelay_tEuSutET_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_x2U2t9Yg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_zIEWU4mZ, HV_BINOP_SUBTRACT, 0, m, &cBinop_zIEWU4mZ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_UVn2p2BT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_23vxXZhO, HV_BINOP_MAX, 0, m, &cBinop_23vxXZhO_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_tAMeuVlz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UVn2p2BT, HV_BINOP_MULTIPLY, 0, m, &cBinop_UVn2p2BT_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_KhKnbVFP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_d1feBMaF_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_x2U2t9Yg, 0, m, &sTabread_x2U2t9Yg_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_N8KGjppQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_uepV1MKf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zIEWU4mZ, HV_BINOP_SUBTRACT, 1, m, &cBinop_zIEWU4mZ_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_tEuSutET, 2, m, &cDelay_tEuSutET_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_5yM49Fze_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_uepV1MKf_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_d1feBMaF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_bhecObMw, 0, m, &cDelay_bhecObMw_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_tEuSutET, 0, m, &cDelay_tEuSutET_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_WQRSo0Q8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_23vxXZhO, HV_BINOP_MAX, 1, m, &cBinop_23vxXZhO_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_23vxXZhO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KhKnbVFP, HV_BINOP_SUBTRACT, 1, m, &cBinop_KhKnbVFP_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_N8KGjppQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_bhecObMw, 0, m, &cDelay_bhecObMw_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_MoiKIqtv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_bhecObMw, 2, m, &cDelay_bhecObMw_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_zIEWU4mZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_MoiKIqtv_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Tiy213rh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lqM360pS, 0, m, &cVar_lqM360pS_sendMessage);
  cMsg_07fheukR_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_73d4VvaX, 0, m, &cTabhead_73d4VvaX_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_TcRqgop8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_WVtDukqO_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_WVtDukqO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_ACdDNxxi_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_xI4EAKlW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_xI4EAKlW, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_tTM2oW6M, 0, m, &cDelay_tTM2oW6M_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_xI4EAKlW, 0, m, &cDelay_xI4EAKlW_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_41AIsxpP, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_tTM2oW6M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_tTM2oW6M, m);
  cMsg_9alqTEIA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_4jKPHbQb_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_OUsopk7r_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_MKvOwRmz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qlHgfEzz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_LDmV5UoC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_u5m4lACx_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_xI4EAKlW, 2, m, &cDelay_xI4EAKlW_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9guW6XJZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_qlHgfEzz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_LDmV5UoC, 0, m, &hTable_LDmV5UoC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ACdDNxxi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_MKvOwRmz_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_9alqTEIA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_LDmV5UoC, 0, m, &hTable_LDmV5UoC_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_9guW6XJZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_xI4EAKlW, 0, m, &cDelay_xI4EAKlW_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_u5m4lACx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_tTM2oW6M, 2, m, &cDelay_tTM2oW6M_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_OUsopk7r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_41AIsxpP, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_1chPiyzJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FlGf6t36, HV_BINOP_SUBTRACT, 0, m, &cBinop_FlGf6t36_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_T6JAPKWQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_PrcFZrb6_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_PrcFZrb6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_pFNkHIzI_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_eK4Jarzo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZTwwhbXV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_zWdrJ0S6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_zWdrJ0S6, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_lXiVLbXV, 0, m, &cDelay_lXiVLbXV_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_ofzDWlSh, 0, m, &sTabread_ofzDWlSh_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_lXiVLbXV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_lXiVLbXV, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_ofzDWlSh, 0, m, &sTabread_ofzDWlSh_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_lXiVLbXV, 0, m, &cDelay_lXiVLbXV_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_ofzDWlSh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_6CmeSeSm, HV_BINOP_SUBTRACT, 0, m, &cBinop_6CmeSeSm_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_eoTNAHKC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_x57YWzXr, HV_BINOP_MAX, 0, m, &cBinop_x57YWzXr_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_pFNkHIzI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eoTNAHKC, HV_BINOP_MULTIPLY, 0, m, &cBinop_eoTNAHKC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_FlGf6t36_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SAa8TWSE_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_ofzDWlSh, 0, m, &sTabread_ofzDWlSh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XHhUKdZD_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_pi4TYgiU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6CmeSeSm, HV_BINOP_SUBTRACT, 1, m, &cBinop_6CmeSeSm_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_lXiVLbXV, 2, m, &cDelay_lXiVLbXV_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ZTwwhbXV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_pi4TYgiU_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_SAa8TWSE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_zWdrJ0S6, 0, m, &cDelay_zWdrJ0S6_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_lXiVLbXV, 0, m, &cDelay_lXiVLbXV_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_PdAQ4c3J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_x57YWzXr, HV_BINOP_MAX, 1, m, &cBinop_x57YWzXr_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_x57YWzXr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FlGf6t36, HV_BINOP_SUBTRACT, 1, m, &cBinop_FlGf6t36_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_XHhUKdZD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_zWdrJ0S6, 0, m, &cDelay_zWdrJ0S6_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ijMMJ9OQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_zWdrJ0S6, 2, m, &cDelay_zWdrJ0S6_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_6CmeSeSm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_ijMMJ9OQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_3Mc478o5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_eK4Jarzo, 0, m, &cVar_eK4Jarzo_sendMessage);
  cMsg_T6JAPKWQ_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_1chPiyzJ, 0, m, &cTabhead_1chPiyzJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_iYaf9Axt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_P1OdeSXT, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_GrBBkgHn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PLysKHh7, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_oNOUNJr6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_dxPE8zkt, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_6GASHk4k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_u6DLfBsS, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_SWKnmyL5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XmaejfVE, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_dQDw4PsS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8LHM389H, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_L6s0GaTA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xKGSX7HE, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_qxXSg4Id_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Kn7buoVW, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cSwitchcase_oh2lm58U_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_B8JZrqiG, 0, m, &cSlice_B8JZrqiG_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_B8JZrqiG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_m92N33cq_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_m92N33cq_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_kGDtnefe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_m92N33cq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_m92N33cq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_nJFkh0pW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_w7eXKLQq_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC8CCFEC1: { // "cross"
      cSlice_onMessage(_c, &Context(_c)->cSlice_uL2SJ8Wb, 0, m, &cSlice_uL2SJ8Wb_sendMessage);
      break;
    }
    default: {
      cSwitchcase_J4mgj6Q5_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_uL2SJ8Wb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_krWiJ3wx_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_krWiJ3wx_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_K9KoNGey_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_krWiJ3wx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_krWiJ3wx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_W5VFado3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_OQz1Gojq_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x8E55AA5F: { // "time"
      cSlice_onMessage(_c, &Context(_c)->cSlice_KfEos8Sl, 0, m, &cSlice_KfEos8Sl_sendMessage);
      break;
    }
    default: {
      cSwitchcase_oh2lm58U_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_KfEos8Sl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_2jmkIOEs_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_2jmkIOEs_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_nWohq1bl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_2jmkIOEs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_2jmkIOEs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ljlY3iJS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_OcJ4vP2m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_VK1Wgp1R_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_VK1Wgp1R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_H6G9tNka_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_QRCrZAl0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_p5CxSuX8_sendMessage(_c, 0, m);
  cMsg_0JYOq8Sw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_48JKUNTE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9CcAoCYq_sendMessage(_c, 0, m);
  cMsg_T2aIerqp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_H6G9tNka_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_3ovVbOjp_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_3ovVbOjp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_24DOTqAZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8bPWZG8A_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_24DOTqAZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_g3tny9uy_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_8bPWZG8A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JDvTtTVJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_g3tny9uy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_xquYWhvA_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_JDvTtTVJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_VTAfdOmE_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_VTAfdOmE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_oc6j17fX_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_xquYWhvA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_QRCrZAl0_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_oc6j17fX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_48JKUNTE_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Qr17Vws5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_OonlN7Jv_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_OonlN7Jv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_aCOeV1PJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_aCOeV1PJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_uFhI3Oc2_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_uFhI3Oc2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7pK1eyEt_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UAmGzGQe_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_UAmGzGQe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BjtDbLqa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_7pK1eyEt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_jnB0QQTd_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_jnB0QQTd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_BMEnCgEu_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_BjtDbLqa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_B8EKRh11_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_B8EKRh11_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_vET3lRQD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_vET3lRQD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NcuNuXYV_sendMessage(_c, 0, m);
  cMsg_kx5WInSu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_BMEnCgEu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eIDu6dWZ_sendMessage(_c, 0, m);
  cMsg_jluMvvvw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_84MCRoIB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_vf4Px6vT_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_vf4Px6vT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_Tci61QbH_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_d5M4uSq8_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_VHt34opl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_3wfOEoUN_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_8JUDYjJW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_PyURsOvc_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_PyURsOvc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IcwjBYnM, HV_BINOP_DIVIDE, 1, m, &cBinop_IcwjBYnM_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Tci61QbH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_9n90ah2v_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9n90ah2v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Mey2ASBG, m);
}

void Heavy_WSTD_DL3Y::cMsg_r4YKCdhM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_AwwPBmVg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_AwwPBmVg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_84MCRoIB_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_d5M4uSq8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_xEOxzlSI, m);
}

void Heavy_WSTD_DL3Y::cBinop_3wfOEoUN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_Mba42Rde_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Mba42Rde_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IcwjBYnM, HV_BINOP_DIVIDE, 0, m, &cBinop_IcwjBYnM_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_IcwjBYnM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_r4YKCdhM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_bNRFfEoI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_cY1Y9GcU_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_cY1Y9GcU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_79adAf31_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_zJYoyNQQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_fCisIMAa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_Q0qAgAn8_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_i7NbhPbD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_fndZKiVr_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_fndZKiVr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_v58GiVeq, HV_BINOP_DIVIDE, 1, m, &cBinop_v58GiVeq_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_79adAf31_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_nEYynokN_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_nEYynokN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_8FkfIvOI, m);
}

void Heavy_WSTD_DL3Y::cMsg_GZLq5KJW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_PfIWG0w5_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_PfIWG0w5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_bNRFfEoI_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_zJYoyNQQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_CzKj2tcE, m);
}

void Heavy_WSTD_DL3Y::cBinop_Q0qAgAn8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_yBsWdsfe_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_yBsWdsfe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_v58GiVeq, HV_BINOP_DIVIDE, 0, m, &cBinop_v58GiVeq_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_v58GiVeq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GZLq5KJW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_EDmkZx5f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XlTIEiWL, HV_BINOP_MULTIPLY, 0, m, &cBinop_XlTIEiWL_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_6SCOZZzV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_NcwdLWbu_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_NcwdLWbu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_f3PV26O3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_XlTIEiWL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_2iHs6Vyf_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_qztVV54o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XlTIEiWL, HV_BINOP_MULTIPLY, 1, m, &cBinop_XlTIEiWL_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_f3PV26O3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_qztVV54o_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_2iHs6Vyf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_fklxLaFn_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_fklxLaFn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_JuHlsl1L_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_eSQ9AtSo, m);
}

void Heavy_WSTD_DL3Y::cBinop_JuHlsl1L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_ezNDdIIq, m);
}

void Heavy_WSTD_DL3Y::cVar_Tq8W4U1G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_st5VIIqh, HV_BINOP_MULTIPLY, 0, m, &cBinop_st5VIIqh_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_jNTvHOTf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_LBB1kc9x_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_LBB1kc9x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3LeqMjh0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_st5VIIqh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_M4KFvDfo_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_qMexPr7o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_st5VIIqh, HV_BINOP_MULTIPLY, 1, m, &cBinop_st5VIIqh_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_3LeqMjh0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_qMexPr7o_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_M4KFvDfo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_tFatx0yF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_tFatx0yF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_CJhhXDT3_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_Zb1HqML6, m);
}

void Heavy_WSTD_DL3Y::cBinop_CJhhXDT3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_qqArUhbb, m);
}

void Heavy_WSTD_DL3Y::sEnv_j98bGlBF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_089EIGpn_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_McwSMhHd_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_jBe0S5nP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_VGCoGo2I_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_nqRps6Jl_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_JUFIAvpm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_78Sn05uf, HV_BINOP_POW, 0, m, &cBinop_78Sn05uf_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_78Sn05uf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RZ6hmDuo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_bIvnfedQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_h9MDa48U_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_McwSMhHd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jBe0S5nP, 0, m, &cIf_jBe0S5nP_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_089EIGpn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_LzeJNbwi_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_LzeJNbwi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jBe0S5nP, 1, m, &cIf_jBe0S5nP_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_nqRps6Jl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_bIvnfedQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_VGCoGo2I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_RZ6hmDuo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_h9MDa48U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_78Sn05uf, HV_BINOP_POW, 1, m, &cBinop_78Sn05uf_sendMessage);
  cMsg_JUFIAvpm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_IIGjUzKt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1wQ7TqQp, HV_BINOP_MULTIPLY, 0, m, &cBinop_1wQ7TqQp_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_XmjysoxO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_NGeW84uB_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_NGeW84uB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_g0uKCCfr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_1wQ7TqQp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_sohvr2g7_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_yljqeN4m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1wQ7TqQp, HV_BINOP_MULTIPLY, 1, m, &cBinop_1wQ7TqQp_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_g0uKCCfr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_yljqeN4m_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_sohvr2g7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_5hwpTAxK_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5hwpTAxK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_iXfdb4V0_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_kWbeYKlB, m);
}

void Heavy_WSTD_DL3Y::cBinop_iXfdb4V0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_FysH86lk, m);
}

void Heavy_WSTD_DL3Y::cMsg_RZ6hmDuo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Bw2O9Drx_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Bw2O9Drx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_6vPnDkx4, m);
}

void Heavy_WSTD_DL3Y::sEnv_HHaHgeMa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9btbJpF1_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_e8XYE0C9_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_SOXXzuiY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_BfEo9H9b_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_hfkFNZoT_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_8jYddbMR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_2sdyeF10, HV_BINOP_POW, 0, m, &cBinop_2sdyeF10_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_2sdyeF10_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OPY71Cwx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_joksKcAj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_EWCfUseE_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_e8XYE0C9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SOXXzuiY, 0, m, &cIf_SOXXzuiY_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_9btbJpF1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_F999hmbO_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_F999hmbO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SOXXzuiY, 1, m, &cIf_SOXXzuiY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_hfkFNZoT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_joksKcAj_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_BfEo9H9b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_OPY71Cwx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_EWCfUseE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2sdyeF10, HV_BINOP_POW, 1, m, &cBinop_2sdyeF10_sendMessage);
  cMsg_8jYddbMR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_I9IOh9DM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DYar3h2O, HV_BINOP_MULTIPLY, 0, m, &cBinop_DYar3h2O_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_pyfIuu3c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_WJHl4avV_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_WJHl4avV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_StQuXXL4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_DYar3h2O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_9Be7INmd_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_kpw4nF2U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DYar3h2O, HV_BINOP_MULTIPLY, 1, m, &cBinop_DYar3h2O_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_StQuXXL4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_kpw4nF2U_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9Be7INmd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_3sxQ5k2u_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_3sxQ5k2u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_a9fbrrpS_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_TAY4jR9W, m);
}

void Heavy_WSTD_DL3Y::cBinop_a9fbrrpS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_uli9YSYT, m);
}

void Heavy_WSTD_DL3Y::cMsg_OPY71Cwx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_FrM1F3lY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_FrM1F3lY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_QEkxL30X, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_J4mgj6Q5_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_gJeOSgX0, 0, m, &cSlice_gJeOSgX0_sendMessage);
      break;
    }
    default: {
      cSwitchcase_OQz1Gojq_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_gJeOSgX0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_BW8pxBpO_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_BW8pxBpO_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_R9WLaEtD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_BW8pxBpO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_BW8pxBpO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_wNZk3dA6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_o8M0NmBJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_q1rAUKKO_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_q1rAUKKO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_DJoJkCqW_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_wJyZhAVY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_wJyZhAVY, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_4dJMnwyg, 0, m, &cDelay_4dJMnwyg_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_wJyZhAVY, 0, m, &cDelay_wJyZhAVY_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_MLrMEAIn, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_4dJMnwyg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_4dJMnwyg, m);
  cMsg_27EF7QL2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_zep8fzkE_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_mxi5hA5t_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_UqimS8gw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ugkznz8p_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_29VDm9Cb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XNRGj0zl_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_wJyZhAVY, 2, m, &cDelay_wJyZhAVY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Unywy44m_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ugkznz8p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_29VDm9Cb, 0, m, &hTable_29VDm9Cb_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_DJoJkCqW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_UqimS8gw_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_27EF7QL2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_29VDm9Cb, 0, m, &hTable_29VDm9Cb_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Unywy44m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_wJyZhAVY, 0, m, &cDelay_wJyZhAVY_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_XNRGj0zl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_4dJMnwyg, 2, m, &cDelay_4dJMnwyg_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_mxi5hA5t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_MLrMEAIn, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_al0QVeVO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2LxMMVPi, HV_BINOP_SUBTRACT, 0, m, &cBinop_2LxMMVPi_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_DyuF0qbb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_QQwRKu0d_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_QQwRKu0d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_Z3wyG9eH_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_mWUiw2VE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yv7o58MV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_bbNJojpM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_bbNJojpM, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ROOQPIuK, 0, m, &cDelay_ROOQPIuK_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_EhqIz5NI, 0, m, &sTabread_EhqIz5NI_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_ROOQPIuK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ROOQPIuK, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_EhqIz5NI, 0, m, &sTabread_EhqIz5NI_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ROOQPIuK, 0, m, &cDelay_ROOQPIuK_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_EhqIz5NI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_zuP89wX0, HV_BINOP_SUBTRACT, 0, m, &cBinop_zuP89wX0_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_yjLQMjOP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qwfV3RnL, HV_BINOP_MAX, 0, m, &cBinop_qwfV3RnL_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Z3wyG9eH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yjLQMjOP, HV_BINOP_MULTIPLY, 0, m, &cBinop_yjLQMjOP_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_2LxMMVPi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LcVkDgq2_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_EhqIz5NI, 0, m, &sTabread_EhqIz5NI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nkXbMICR_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_G4PLIJxW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zuP89wX0, HV_BINOP_SUBTRACT, 1, m, &cBinop_zuP89wX0_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ROOQPIuK, 2, m, &cDelay_ROOQPIuK_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_yv7o58MV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_G4PLIJxW_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_LcVkDgq2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_bbNJojpM, 0, m, &cDelay_bbNJojpM_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ROOQPIuK, 0, m, &cDelay_ROOQPIuK_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_LL5i5zZs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_qwfV3RnL, HV_BINOP_MAX, 1, m, &cBinop_qwfV3RnL_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_qwfV3RnL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2LxMMVPi, HV_BINOP_SUBTRACT, 1, m, &cBinop_2LxMMVPi_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_nkXbMICR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_bbNJojpM, 0, m, &cDelay_bbNJojpM_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_kvv2bPUf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_bbNJojpM, 2, m, &cDelay_bbNJojpM_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_zuP89wX0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_kvv2bPUf_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_pKhcU4hB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_mWUiw2VE, 0, m, &cVar_mWUiw2VE_sendMessage);
  cMsg_DyuF0qbb_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_al0QVeVO, 0, m, &cTabhead_al0QVeVO_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_yzbDqSgt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_7DqaYHtH_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_7DqaYHtH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_JHyzOIM1_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_0F7mRIQR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_0F7mRIQR, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_fRYPmMFu, 0, m, &cDelay_fRYPmMFu_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_0F7mRIQR, 0, m, &cDelay_0F7mRIQR_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_bbqCH68Y, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_fRYPmMFu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_fRYPmMFu, m);
  cMsg_BBgaSXlk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_cwfm20J4_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_oaJhHLPU_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_3xS1J7Zl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DzmZfcQe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_NizuKVeo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aXpc4BDR_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_0F7mRIQR, 2, m, &cDelay_0F7mRIQR_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Vp92nXyX_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_DzmZfcQe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_NizuKVeo, 0, m, &hTable_NizuKVeo_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JHyzOIM1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_3xS1J7Zl_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_BBgaSXlk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_NizuKVeo, 0, m, &hTable_NizuKVeo_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Vp92nXyX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_0F7mRIQR, 0, m, &cDelay_0F7mRIQR_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_aXpc4BDR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_fRYPmMFu, 2, m, &cDelay_fRYPmMFu_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_oaJhHLPU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_bbqCH68Y, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_JEowga8n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oZAmLeSi, HV_BINOP_SUBTRACT, 0, m, &cBinop_oZAmLeSi_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_S2MBl9zp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ylMcV18G_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_ylMcV18G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_pSk8LAIp_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_8N75hqps_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eUih98bN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_xC5meA2z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_xC5meA2z, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Mch09k6i, 0, m, &cDelay_Mch09k6i_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_lMZcOwpF, 0, m, &sTabread_lMZcOwpF_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_Mch09k6i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Mch09k6i, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_lMZcOwpF, 0, m, &sTabread_lMZcOwpF_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Mch09k6i, 0, m, &cDelay_Mch09k6i_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_lMZcOwpF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_WLpFsj3y, HV_BINOP_SUBTRACT, 0, m, &cBinop_WLpFsj3y_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_7SPdBQ8H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gVfdMoL9, HV_BINOP_MAX, 0, m, &cBinop_gVfdMoL9_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_pSk8LAIp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7SPdBQ8H, HV_BINOP_MULTIPLY, 0, m, &cBinop_7SPdBQ8H_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_oZAmLeSi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8Jk8wJ00_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_lMZcOwpF, 0, m, &sTabread_lMZcOwpF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hZng8GnF_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_GUfy46FY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WLpFsj3y, HV_BINOP_SUBTRACT, 1, m, &cBinop_WLpFsj3y_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Mch09k6i, 2, m, &cDelay_Mch09k6i_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_eUih98bN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_GUfy46FY_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_8Jk8wJ00_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_xC5meA2z, 0, m, &cDelay_xC5meA2z_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Mch09k6i, 0, m, &cDelay_Mch09k6i_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ygg3veFp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_gVfdMoL9, HV_BINOP_MAX, 1, m, &cBinop_gVfdMoL9_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_gVfdMoL9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oZAmLeSi, HV_BINOP_SUBTRACT, 1, m, &cBinop_oZAmLeSi_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_hZng8GnF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_xC5meA2z, 0, m, &cDelay_xC5meA2z_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_jhfUkzlr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_xC5meA2z, 2, m, &cDelay_xC5meA2z_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_WLpFsj3y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_jhfUkzlr_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_QoItzTQF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8N75hqps, 0, m, &cVar_8N75hqps_sendMessage);
  cMsg_S2MBl9zp_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_JEowga8n, 0, m, &cTabhead_JEowga8n_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_p5CxSuX8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9NHUefnY, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_9CcAoCYq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_EqXIZ3nf, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_T2aIerqp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7VwmSCXX, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_0JYOq8Sw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9BxoFLfS, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_jluMvvvw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ebHEI9Se, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_NcuNuXYV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_KkmMQoEr, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_eIDu6dWZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_My6wt8xb, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_kx5WInSu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mwRC6e9e, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cVar_POgMvsVH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_yRW5uxaB_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_lp0fputx_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_qD3kHOm9_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_yRW5uxaB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_POgMvsVH, 1, m, &cVar_POgMvsVH_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_BUhKXsF3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_4xLNnZQa, 0, m, &cVar_4xLNnZQa_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_U6olv1Tr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_4xLNnZQa, 0, m, &cVar_4xLNnZQa_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_PFBMaJEw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_U6olv1Tr, 0, m, &cIf_U6olv1Tr_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_QxrH9wab_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BUhKXsF3, 0, m, &cIf_BUhKXsF3_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_cQe4j39W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Nrgbtw5x_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_O2TvMaFA_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_3i28Jh5G_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Nrgbtw5x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_cQe4j39W, 1, m, &cVar_cQe4j39W_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_8YVPzwcd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_2kMIXZHK, 0, m, &cVar_2kMIXZHK_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_pHVc6bkb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_2kMIXZHK, 0, m, &cVar_2kMIXZHK_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_cjXW0dFB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pHVc6bkb, 0, m, &cIf_pHVc6bkb_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_zGUgKoEG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8YVPzwcd, 0, m, &cIf_8YVPzwcd_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_X3UyUhOh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ezFQKuIw_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_2deHtR3m_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_a6U6YWYM_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ezFQKuIw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_X3UyUhOh, 1, m, &cVar_X3UyUhOh_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_UPP0FQG4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_boeOssgK, 0, m, &cVar_boeOssgK_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_4nIYU2uh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_boeOssgK, 0, m, &cVar_boeOssgK_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_BcvNmYES_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4nIYU2uh, 0, m, &cIf_4nIYU2uh_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_Xwo59aWt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_UPP0FQG4, 0, m, &cIf_UPP0FQG4_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_V4EQthnS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_io2LWTEM, HV_BINOP_DIVIDE, 0, m, &cBinop_io2LWTEM_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_mtRGjX1g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iMrLZHfK, HV_BINOP_MULTIPLY, 1, m, &cBinop_iMrLZHfK_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_vZF4w1wp_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_aGFgnniI, 0, m, &cSlice_aGFgnniI_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_IVosIeED, 0, m, &cSlice_IVosIeED_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pgdlC9z9_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DbOs9Q9O_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_aGFgnniI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_fqztuJ79, 0, m, &cVar_fqztuJ79_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_fqztuJ79, 0, m, &cVar_fqztuJ79_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cSlice_IVosIeED_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_a5iE5kTY, HV_BINOP_NEQ, 1, m, &cBinop_a5iE5kTY_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_fqztuJ79, 1, m, &cVar_fqztuJ79_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_a5iE5kTY, HV_BINOP_NEQ, 1, m, &cBinop_a5iE5kTY_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_fqztuJ79, 1, m, &cVar_fqztuJ79_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_fqztuJ79_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 5000.0f, 0, m, &cBinop_H7seLGNl_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_OkNDHXsM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bns8nybO_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UXPLaX6J_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cCast_bns8nybO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_a5iE5kTY, HV_BINOP_NEQ, 1, m, &cBinop_a5iE5kTY_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_UXPLaX6J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_fqztuJ79, 0, m, &cVar_fqztuJ79_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_a5iE5kTY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_OkNDHXsM, 1, m, &cIf_OkNDHXsM_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_DbOs9Q9O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_OkNDHXsM, 0, m, &cIf_OkNDHXsM_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_pgdlC9z9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_a5iE5kTY, HV_BINOP_NEQ, 0, m, &cBinop_a5iE5kTY_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_f6VxDIRT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yWdVLceh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7mNmwMXN_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_Z8sBiUJL_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Pmifgp9u_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kCOjLS6a_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_muLCegyY_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QEnyesW6_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5mNKyS5x_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_R2rDTchV_sendMessage);
      break;
    }
    case 0x40C00000: { // "6.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OzrRMpJx_sendMessage);
      break;
    }
    case 0x40E00000: { // "7.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MFyBfJdZ_sendMessage);
      break;
    }
    case 0x41000000: { // "8.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xW04nqo0_sendMessage);
      break;
    }
    case 0x41100000: { // "9.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OQ7Yy7Xk_sendMessage);
      break;
    }
    case 0x41200000: { // "10.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dPcxYZnB_sendMessage);
      break;
    }
    case 0x41300000: { // "11.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YtH8Q7ES_sendMessage);
      break;
    }
    case 0x41400000: { // "12.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_USN2eBN8_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cCast_Pmifgp9u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_u4FEO1to_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_kCOjLS6a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BSsCZnpW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_muLCegyY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iPNojaqB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_QEnyesW6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9jCkRlbq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_5mNKyS5x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PVj1mSJt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_R2rDTchV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Vyj6AOQv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_OzrRMpJx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_m432AVyM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_MFyBfJdZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Hv52CN09_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_xW04nqo0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_br968FeR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_OQ7Yy7Xk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_K2kTUaaD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_dPcxYZnB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rRmnIDvz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_YtH8Q7ES_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qRU4CfOz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_USN2eBN8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VUys83zy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_io2LWTEM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iMrLZHfK, HV_BINOP_MULTIPLY, 0, m, &cBinop_iMrLZHfK_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_iMrLZHfK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_vZF4w1wp_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cCast_7mNmwMXN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_V4EQthnS, 0, m, &cVar_V4EQthnS_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_mtRGjX1g, 0, m, &cVar_mtRGjX1g_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_yWdVLceh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_io2LWTEM, HV_BINOP_DIVIDE, 1, m, &cBinop_io2LWTEM_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_327DYfPT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_V4EQthnS, 0, m, &cVar_V4EQthnS_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_rAqDPc6y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_mtRGjX1g, 0, m, &cVar_mtRGjX1g_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_u4FEO1to_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.166667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rAqDPc6y_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_327DYfPT_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_BSsCZnpW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.2f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rAqDPc6y_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_327DYfPT_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_iPNojaqB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.25f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rAqDPc6y_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_327DYfPT_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_9jCkRlbq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.333333f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rAqDPc6y_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_327DYfPT_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_PVj1mSJt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.6f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rAqDPc6y_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_327DYfPT_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Vyj6AOQv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.666667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rAqDPc6y_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_327DYfPT_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_m432AVyM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rAqDPc6y_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_327DYfPT_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Hv52CN09_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.5f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rAqDPc6y_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_327DYfPT_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_br968FeR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 2.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rAqDPc6y_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_327DYfPT_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_K2kTUaaD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 3.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rAqDPc6y_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_327DYfPT_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_rRmnIDvz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 4.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rAqDPc6y_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_327DYfPT_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_qRU4CfOz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 5.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rAqDPc6y_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_327DYfPT_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_VUys83zy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rAqDPc6y_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_327DYfPT_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_QKZbj1QA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_omn0lBrZ, HV_BINOP_DIVIDE, 0, m, &cBinop_omn0lBrZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_ytMfq5jm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AlhX2Zva, HV_BINOP_MULTIPLY, 1, m, &cBinop_AlhX2Zva_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_NRaRevDT_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_KdWVisBO, 0, m, &cSlice_KdWVisBO_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_z9osDnah, 0, m, &cSlice_z9osDnah_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UpCw8vjr_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lbncfWEH_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_KdWVisBO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_l5sk1Gca, 0, m, &cVar_l5sk1Gca_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_l5sk1Gca, 0, m, &cVar_l5sk1Gca_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cSlice_z9osDnah_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_iAVPaBaF, HV_BINOP_NEQ, 1, m, &cBinop_iAVPaBaF_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_l5sk1Gca, 1, m, &cVar_l5sk1Gca_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_iAVPaBaF, HV_BINOP_NEQ, 1, m, &cBinop_iAVPaBaF_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_l5sk1Gca, 1, m, &cVar_l5sk1Gca_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_l5sk1Gca_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 5000.0f, 0, m, &cBinop_DAPMAdZp_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_rwUNOg5Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wxi9YfKk_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VhozrNXk_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cCast_VhozrNXk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_l5sk1Gca, 0, m, &cVar_l5sk1Gca_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_wxi9YfKk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iAVPaBaF, HV_BINOP_NEQ, 1, m, &cBinop_iAVPaBaF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_iAVPaBaF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rwUNOg5Z, 1, m, &cIf_rwUNOg5Z_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_lbncfWEH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rwUNOg5Z, 0, m, &cIf_rwUNOg5Z_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_UpCw8vjr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iAVPaBaF, HV_BINOP_NEQ, 0, m, &cBinop_iAVPaBaF_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_cTlYKZLS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1viXlAgQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KnD7yxU1_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_Eht9pcEl_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JrXajHXa_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_13Dm2NLI_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_G1NoO8aa_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lcJ5eM6S_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_S6kkwtNq_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_M4UnHow3_sendMessage);
      break;
    }
    case 0x40C00000: { // "6.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uL5GHvkZ_sendMessage);
      break;
    }
    case 0x40E00000: { // "7.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LGhzcir7_sendMessage);
      break;
    }
    case 0x41000000: { // "8.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Xp4E4pPL_sendMessage);
      break;
    }
    case 0x41100000: { // "9.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ya8KibMt_sendMessage);
      break;
    }
    case 0x41200000: { // "10.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cdvw6GDP_sendMessage);
      break;
    }
    case 0x41300000: { // "11.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8LmQJXZC_sendMessage);
      break;
    }
    case 0x41400000: { // "12.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZCHrbfCl_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cCast_JrXajHXa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_O8HuweHL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_13Dm2NLI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9YLkBDql_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_G1NoO8aa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RKk4GpUP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_lcJ5eM6S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kQUcEW0T_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_S6kkwtNq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NQLdGCmg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_M4UnHow3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rklJl0AC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_uL5GHvkZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ELCGCCho_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_LGhzcir7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KgcBBJ3B_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_Xp4E4pPL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UN1PfqXn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_ya8KibMt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fIj390c6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_cdvw6GDP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zaQ3FWDC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_8LmQJXZC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_M7xYP5qj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_ZCHrbfCl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_l50HBI0W_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_omn0lBrZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AlhX2Zva, HV_BINOP_MULTIPLY, 0, m, &cBinop_AlhX2Zva_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_AlhX2Zva_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_NRaRevDT_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cCast_KnD7yxU1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_QKZbj1QA, 0, m, &cVar_QKZbj1QA_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ytMfq5jm, 0, m, &cVar_ytMfq5jm_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_1viXlAgQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_omn0lBrZ, HV_BINOP_DIVIDE, 1, m, &cBinop_omn0lBrZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_c5OPdWyY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_QKZbj1QA, 0, m, &cVar_QKZbj1QA_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_n9RXLvKS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ytMfq5jm, 0, m, &cVar_ytMfq5jm_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_O8HuweHL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.166667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_n9RXLvKS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_c5OPdWyY_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_9YLkBDql_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.2f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_n9RXLvKS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_c5OPdWyY_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_RKk4GpUP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.25f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_n9RXLvKS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_c5OPdWyY_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_kQUcEW0T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.333333f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_n9RXLvKS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_c5OPdWyY_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_NQLdGCmg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.6f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_n9RXLvKS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_c5OPdWyY_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_rklJl0AC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.666667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_n9RXLvKS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_c5OPdWyY_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ELCGCCho_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_n9RXLvKS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_c5OPdWyY_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_KgcBBJ3B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.5f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_n9RXLvKS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_c5OPdWyY_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_UN1PfqXn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 2.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_n9RXLvKS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_c5OPdWyY_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_fIj390c6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 3.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_n9RXLvKS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_c5OPdWyY_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_zaQ3FWDC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 4.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_n9RXLvKS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_c5OPdWyY_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_M7xYP5qj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 5.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_n9RXLvKS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_c5OPdWyY_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_l50HBI0W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_n9RXLvKS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_c5OPdWyY_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_xW9sznDx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yst2cxzW, HV_BINOP_DIVIDE, 0, m, &cBinop_yst2cxzW_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_FrtmmIEg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nBVfv5np, HV_BINOP_MULTIPLY, 1, m, &cBinop_nBVfv5np_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_LRi66n5c_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_XIZpCDOg, 0, m, &cSlice_XIZpCDOg_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_3liwz9dW, 0, m, &cSlice_3liwz9dW_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EpvMF2su_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wViENfQm_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_XIZpCDOg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_IKh7Xang, 0, m, &cVar_IKh7Xang_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_IKh7Xang, 0, m, &cVar_IKh7Xang_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cSlice_3liwz9dW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_XL8DP6RI, HV_BINOP_NEQ, 1, m, &cBinop_XL8DP6RI_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_IKh7Xang, 1, m, &cVar_IKh7Xang_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_XL8DP6RI, HV_BINOP_NEQ, 1, m, &cBinop_XL8DP6RI_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_IKh7Xang, 1, m, &cVar_IKh7Xang_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_IKh7Xang_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 5000.0f, 0, m, &cBinop_0mH50qfH_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_Qvcvv7xR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SpijD93B_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LnRU7Q0o_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cCast_SpijD93B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XL8DP6RI, HV_BINOP_NEQ, 1, m, &cBinop_XL8DP6RI_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_LnRU7Q0o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_IKh7Xang, 0, m, &cVar_IKh7Xang_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_XL8DP6RI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Qvcvv7xR, 1, m, &cIf_Qvcvv7xR_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_wViENfQm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Qvcvv7xR, 0, m, &cIf_Qvcvv7xR_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_EpvMF2su_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XL8DP6RI, HV_BINOP_NEQ, 0, m, &cBinop_XL8DP6RI_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_2kdp05y7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hiBc9xO2_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_x2RAEGYv_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_VtiL81uq_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NxEF4NPt_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iemCnDLT_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JURbsmfh_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Oa0jPASQ_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yt8gZBiO_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OtDzXKoY_sendMessage);
      break;
    }
    case 0x40C00000: { // "6.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QzMdn18P_sendMessage);
      break;
    }
    case 0x40E00000: { // "7.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rZmjttab_sendMessage);
      break;
    }
    case 0x41000000: { // "8.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UDQvnjik_sendMessage);
      break;
    }
    case 0x41100000: { // "9.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_h21agCV8_sendMessage);
      break;
    }
    case 0x41200000: { // "10.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IpuRwGLo_sendMessage);
      break;
    }
    case 0x41300000: { // "11.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_M41HHzVy_sendMessage);
      break;
    }
    case 0x41400000: { // "12.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yM62uCOE_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cCast_NxEF4NPt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qUthbxVv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_iemCnDLT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XiAhv3te_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_JURbsmfh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3winYxj5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_Oa0jPASQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UfcCFWri_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_yt8gZBiO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8PKEO1wE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_OtDzXKoY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BHlWFlBK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_QzMdn18P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TRcO6hN3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_rZmjttab_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iCoLmYRE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_UDQvnjik_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VuQr1nzt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_h21agCV8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fDeMagcb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_IpuRwGLo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QMabZ0ib_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_M41HHzVy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KTaTxHm6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_yM62uCOE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JJT9VvmX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_yst2cxzW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nBVfv5np, HV_BINOP_MULTIPLY, 0, m, &cBinop_nBVfv5np_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_nBVfv5np_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_LRi66n5c_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cCast_hiBc9xO2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yst2cxzW, HV_BINOP_DIVIDE, 1, m, &cBinop_yst2cxzW_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_x2RAEGYv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xW9sznDx, 0, m, &cVar_xW9sznDx_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_FrtmmIEg, 0, m, &cVar_FrtmmIEg_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_R4Z5p645_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xW9sznDx, 0, m, &cVar_xW9sznDx_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_4FfffqdN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FrtmmIEg, 0, m, &cVar_FrtmmIEg_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_qUthbxVv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.166667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4FfffqdN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_R4Z5p645_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_XiAhv3te_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.2f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4FfffqdN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_R4Z5p645_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_3winYxj5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.25f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4FfffqdN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_R4Z5p645_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_UfcCFWri_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.333333f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4FfffqdN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_R4Z5p645_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_8PKEO1wE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.6f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4FfffqdN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_R4Z5p645_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_BHlWFlBK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.666667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4FfffqdN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_R4Z5p645_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_TRcO6hN3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4FfffqdN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_R4Z5p645_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_iCoLmYRE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.5f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4FfffqdN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_R4Z5p645_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_VuQr1nzt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 2.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4FfffqdN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_R4Z5p645_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_fDeMagcb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 3.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4FfffqdN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_R4Z5p645_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_QMabZ0ib_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 4.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4FfffqdN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_R4Z5p645_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_KTaTxHm6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 5.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4FfffqdN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_R4Z5p645_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_JJT9VvmX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4FfffqdN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_R4Z5p645_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_v5QUUWCa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "highvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_oSP7S87N_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_GBbfKaHE_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_Ykb7Y55d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_oSP7S87N_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_GBbfKaHE_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_tWqRnw4M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lowvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_oSP7S87N_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_GBbfKaHE_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_1bxfKpTH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midfreq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_oSP7S87N_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_GBbfKaHE_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_uAlqv1P4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_oSP7S87N_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_GBbfKaHE_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_UYUBSIc4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1337.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_e7j6nn4t, 0, m, &cVar_e7j6nn4t_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_B6wtUjdn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_vQXLxu8f, 0, m, &cVar_vQXLxu8f_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_SJM0ySRy, 0, m, &cVar_SJM0ySRy_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_cIej8H7r, 0, m, &cVar_cIej8H7r_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_SBTh4WwO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_WH8vDZEu_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_GJySKLDk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_WH8vDZEu_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cBinop_WzxWQxMx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_eGxjHHDh, 0, m, &cVar_eGxjHHDh_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_N18qb0I7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4D84bAof, 0, m, &cVar_4D84bAof_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_gxHPX9fO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1fzLLmHs, 0, m, &cVar_1fzLLmHs_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_mi4zUa3B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "time");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_WH8vDZEu_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_orYfVm0l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "cross");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_WH8vDZEu_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_ow3KOD0A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_Sb3Roju7_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_QXTkNRmM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_Sb3Roju7_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cBinop_ZVOqFmjA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ohIdpqxw, 0, m, &cVar_ohIdpqxw_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_tBJApRAe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_89NvpIVT, 0, m, &cVar_89NvpIVT_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_O73wBX98_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Rh2uejpk, 0, m, &cVar_Rh2uejpk_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ZCdabuEF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "time");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_Sb3Roju7_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_G5coDW6G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "cross");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_Sb3Roju7_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_4n1FQ3JZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_w7eXKLQq_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_JOpnzVoZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_w7eXKLQq_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cBinop_PfFDAqWW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_dYK79nh6, 0, m, &cVar_dYK79nh6_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_wBjRfYrO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_57L0GOvH, 0, m, &cVar_57L0GOvH_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_oSH4fsXv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xqeCbU0Y, 0, m, &cVar_xqeCbU0Y_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_CB3RKang_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "time");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_w7eXKLQq_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_KjQQdMQY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "cross");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_w7eXKLQq_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cBinop_H7seLGNl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_QxrH9wab, 0, m, &cVar_QxrH9wab_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_qD3kHOm9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PqSWhFKS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZKko5OYZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_lp0fputx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rKwPqhk1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rpWEn3mL_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_rpWEn3mL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PFBMaJEw, 0, m, &cVar_PFBMaJEw_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_rKwPqhk1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_U6olv1Tr, 1, m, &cIf_U6olv1Tr_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_PqSWhFKS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BUhKXsF3, 1, m, &cIf_BUhKXsF3_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ZKko5OYZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_QxrH9wab, 0, m, &cVar_QxrH9wab_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_DAPMAdZp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zGUgKoEG, 0, m, &cVar_zGUgKoEG_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_3i28Jh5G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5M1rYbNc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bazuNxvG_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_O2TvMaFA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vzaoc6Hj_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QKYirAF7_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_QKYirAF7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_cjXW0dFB, 0, m, &cVar_cjXW0dFB_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_vzaoc6Hj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pHVc6bkb, 1, m, &cIf_pHVc6bkb_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_5M1rYbNc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8YVPzwcd, 1, m, &cIf_8YVPzwcd_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_bazuNxvG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zGUgKoEG, 0, m, &cVar_zGUgKoEG_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_0mH50qfH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Xwo59aWt, 0, m, &cVar_Xwo59aWt_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_a6U6YWYM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_69wy7iBu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6a0ZtG6J_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_2deHtR3m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PHMLLnnv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NPWg8tOO_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_PHMLLnnv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4nIYU2uh, 1, m, &cIf_4nIYU2uh_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_NPWg8tOO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_BcvNmYES, 0, m, &cVar_BcvNmYES_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_69wy7iBu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_UPP0FQG4, 1, m, &cIf_UPP0FQG4_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_6a0ZtG6J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Xwo59aWt, 0, m, &cVar_Xwo59aWt_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_s8GTXBWw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vQXLxu8f, 0, m, &cVar_vQXLxu8f_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_8TORVN1y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_SJM0ySRy, 0, m, &cVar_SJM0ySRy_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_au9wZ7Ba_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_cIej8H7r, 0, m, &cVar_cIej8H7r_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_oDG18UOJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WVQT39BW, 0, m, &cVar_WVQT39BW_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_46GusISW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pFTdp3D5_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mkvw0qDw_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_X4lm9zQV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_azF8C4R6_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EgEYB7ue_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Fsl3tXuH_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_IfqCXE0v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DZtp7xR4_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kq8ublOW_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rI8bZ8GR_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_EDOiQRq1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_INcr5T44_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qDgNIFlZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iH6h6upI_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_AyeLjaY0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FsmqbMI9_sendMessage(_c, 0, m);
  cMsg_s8uE0jg6_sendMessage(_c, 0, m);
  cMsg_X4nfG7LM_sendMessage(_c, 0, m);
  cMsg_zGrzOAT1_sendMessage(_c, 0, m);
  cMsg_16b5XcWh_sendMessage(_c, 0, m);
  cMsg_PL7Dqdeu_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_IIfnvSIG, 0, m, &cVar_IIfnvSIG_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_WVQT39BW, 0, m, &cVar_WVQT39BW_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_MxZQKyRp, 0, m, &cVar_MxZQKyRp_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_S4B3aV9u, 0, m, &cVar_S4B3aV9u_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_XGikqTeD, 0, m, &cVar_XGikqTeD_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_2dt5mPi6, 0, m, &cVar_2dt5mPi6_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_RT1nkx3t, 0, m, &cVar_RT1nkx3t_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_c8OfgimG, 0, m, &cVar_c8OfgimG_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_uBb2kzOA, 0, m, &cVar_uBb2kzOA_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_hA9VnOW7, 0, m, &cVar_hA9VnOW7_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_7nIZcxWA, 0, m, &cVar_7nIZcxWA_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_lTBlOzWF, 0, m, &cVar_lTBlOzWF_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_73E1FTrW, 0, m, &cVar_73E1FTrW_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_jygwXD0R, 0, m, &cVar_jygwXD0R_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_gU9dF0aN, 0, m, &cVar_gU9dF0aN_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Ixb8M9k4, 0, m, &cVar_Ixb8M9k4_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_4N3znSAu, 0, m, &cVar_4N3znSAu_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_yNeTV4qH, 0, m, &cVar_yNeTV4qH_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_HGn0lA2X, 0, m, &cVar_HGn0lA2X_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_gOr7IVzh, 0, m, &cVar_gOr7IVzh_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_coZegqn7, 0, m, &cVar_coZegqn7_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_rn2jMZab, 0, m, &cVar_rn2jMZab_sendMessage);
  cMsg_FfSLoJ0l_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_JQ0GI58W, 0, m, &cVar_JQ0GI58W_sendMessage);
  cMsg_PEcgrQZr_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_tRIBZwXh, 0, m, &cVar_tRIBZwXh_sendMessage);
  cMsg_0oF1d4ps_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_UHcTmef7, 0, m, &cVar_UHcTmef7_sendMessage);
  cMsg_8ihG5qwO_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_abNhgbxk, 0, m, &cVar_abNhgbxk_sendMessage);
  cMsg_XmjysoxO_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_IIGjUzKt, 0, m, &cVar_IIGjUzKt_sendMessage);
  cMsg_pyfIuu3c_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_I9IOh9DM, 0, m, &cVar_I9IOh9DM_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_a1w8mscN, 0, m, &cVar_a1w8mscN_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Ijm8onJJ, 0, m, &cVar_Ijm8onJJ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_5McP8Xud, 0, m, &cVar_5McP8Xud_sendMessage);
  cMsg_nbeYmglS_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_5MV5sneD, 0, m, &cVar_5MV5sneD_sendMessage);
  cMsg_lpDxvIq0_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_xVdqLggW, 0, m, &cVar_xVdqLggW_sendMessage);
  cMsg_GC3z2zml_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_ayHvAT7o, 0, m, &cVar_ayHvAT7o_sendMessage);
  cMsg_LmKFzBHq_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_fJRcAHjS, 0, m, &cVar_fJRcAHjS_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_9e2Rbmrf, 0, m, &cVar_9e2Rbmrf_sendMessage);
  cMsg_zb7Y2hgo_sendMessage(_c, 0, m);
  cMsg_KSkO4m1S_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_7ZmVbcnL, 0, m, &cVar_7ZmVbcnL_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_n07xxocL, 0, m, &cVar_n07xxocL_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_w1bg2pdl, 0, m, &cVar_w1bg2pdl_sendMessage);
  cMsg_h8VIossZ_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_VCun9Kn1, 0, m, &cVar_VCun9Kn1_sendMessage);
  cMsg_uqwNpXXA_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_LY4gasBz, 0, m, &cVar_LY4gasBz_sendMessage);
  cMsg_tZIrcO9x_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_YWFkZvpr, 0, m, &cVar_YWFkZvpr_sendMessage);
  cMsg_xY3Z7T50_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_Vdjluy0T, 0, m, &cVar_Vdjluy0T_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_tCuMRKRD, 0, m, &cVar_tCuMRKRD_sendMessage);
  cMsg_kITeRI81_sendMessage(_c, 0, m);
  cMsg_TcRqgop8_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_kGDtnefe, 0, m, &cVar_kGDtnefe_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_K9KoNGey, 0, m, &cVar_K9KoNGey_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_nWohq1bl, 0, m, &cVar_nWohq1bl_sendMessage);
  cMsg_8JUDYjJW_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_VHt34opl, 0, m, &cVar_VHt34opl_sendMessage);
  cMsg_i7NbhPbD_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_fCisIMAa, 0, m, &cVar_fCisIMAa_sendMessage);
  cMsg_6SCOZZzV_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_EDmkZx5f, 0, m, &cVar_EDmkZx5f_sendMessage);
  cMsg_jNTvHOTf_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_Tq8W4U1G, 0, m, &cVar_Tq8W4U1G_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_R9WLaEtD, 0, m, &cVar_R9WLaEtD_sendMessage);
  cMsg_o8M0NmBJ_sendMessage(_c, 0, m);
  cMsg_yzbDqSgt_sendMessage(_c, 0, m);
  cMsg_B6wtUjdn_sendMessage(_c, 0, m);
  cMsg_UYUBSIc4_sendMessage(_c, 0, m);
  cMsg_wfEgFuYO_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_3ShYUhrc, 0, m, &cVar_3ShYUhrc_sendMessage);
  cMsg_BpGQWXar_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_qoIw022e, 0, m, &cTabhead_qoIw022e_sendMessage);
  cMsg_m9DZW5TX_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_YxyQ7ffb, 0, m, &cVar_YxyQ7ffb_sendMessage);
  cMsg_uLUjw0l1_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_ofqcEpTF, 0, m, &cTabhead_ofqcEpTF_sendMessage);
  cMsg_WQRSo0Q8_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_lqM360pS, 0, m, &cVar_lqM360pS_sendMessage);
  cMsg_07fheukR_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_73d4VvaX, 0, m, &cTabhead_73d4VvaX_sendMessage);
  cMsg_PdAQ4c3J_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_eK4Jarzo, 0, m, &cVar_eK4Jarzo_sendMessage);
  cMsg_T6JAPKWQ_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_1chPiyzJ, 0, m, &cTabhead_1chPiyzJ_sendMessage);
  cMsg_LL5i5zZs_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_mWUiw2VE, 0, m, &cVar_mWUiw2VE_sendMessage);
  cMsg_DyuF0qbb_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_al0QVeVO, 0, m, &cTabhead_al0QVeVO_sendMessage);
  cMsg_ygg3veFp_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_8N75hqps, 0, m, &cVar_8N75hqps_sendMessage);
  cMsg_S2MBl9zp_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_JEowga8n, 0, m, &cTabhead_JEowga8n_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_tNHcIIUM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mQ4si676, HV_BINOP_MULTIPLY, 0, m, &cBinop_mQ4si676_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_jXKP0n8t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_sSvR5uDI_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_IUSIiH7e_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_tdgkiLWI_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_LGeRYrAD_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_MwRny1Wn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_lQPgZDpV_sendMessage);
  cMsg_3hS9kPRl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_xEqPfHZu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_l9Ia4XUM, HV_BINOP_MULTIPLY, 0, m, &cBinop_l9Ia4XUM_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_ooBu7uM3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_q0N4Up9V_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_cg9zb3Hx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RybKQ2hC, HV_BINOP_MULTIPLY, 1, m, &cBinop_RybKQ2hC_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_TTcYRDP3_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_U7M2BE2V_sendMessage);
  cMsg_LdgywwMt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_1XUzBEvj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uo4MLQxX, HV_BINOP_MULTIPLY, 0, m, &cBinop_uo4MLQxX_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_zZg6JXDR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iBKK1tII_sendMessage(_c, 0, m);
  cMsg_bbeHnZzb_sendMessage(_c, 0, m);
  cMsg_yhk142DU_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_j9Lc7ly7_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_9RfMaMjT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_SIbnxqkh_sendMessage);
  cMsg_rsbl8KuO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_MfzTaWKO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_XGikqTeD, 0, m, &cVar_XGikqTeD_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_WRVyVj5l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EsrcEyAH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sh5ZFNGP_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_qu6k4DPL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nZ330imf_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_riejjkrG_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cjjeMAhW_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_4YCSqKpW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YcMbejhA_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_stEMDTxg_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YSIUQ1vr_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_6pXvPuIA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AExKm5u9_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JBTZse24_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2A8W41FX_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_uoKpAINg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NK7R2OhK, HV_BINOP_MULTIPLY, 0, m, &cBinop_NK7R2OhK_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_QOeucAqD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_GfsE6d2E_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_e65MrBhl_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_1r9lM5qJ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_YYx8pa2J_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_EHKMiKT8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_mEt0zIJC_sendMessage);
  cMsg_YLxxyLmB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_si9cLD9G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_D6NXiTna, HV_BINOP_MULTIPLY, 0, m, &cBinop_D6NXiTna_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_3fJ0mtQN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_PWusEGHI_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_K83qHObA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4pHYAhc8, HV_BINOP_MULTIPLY, 1, m, &cBinop_4pHYAhc8_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_r9KJKZ1e_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_3l6riiQP_sendMessage);
  cMsg_jQyTDdwv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_GXZFpwJq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lheuA62s, HV_BINOP_MULTIPLY, 0, m, &cBinop_lheuA62s_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_t3codlLV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oWJw48PC_sendMessage(_c, 0, m);
  cMsg_xiN845zO_sendMessage(_c, 0, m);
  cMsg_Xp7E7F23_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_0elq90yn_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_QUiVWvfz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_6ZCAAtKI_sendMessage);
  cMsg_uYFSnJCX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_WF52O2bZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_e7j6nn4t, 0, m, &cVar_e7j6nn4t_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_ChHOzsV4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_WzxWQxMx_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_uyhRunyX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_N18qb0I7_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_RPDIuikB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_gxHPX9fO_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_1Vgaq1hp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_ZVOqFmjA_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_yBY5s7bg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_tBJApRAe_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_VPrsJK72_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_PfFDAqWW_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_CyWpuAUl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_wBjRfYrO_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_SbA4RIyY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_oSH4fsXv_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_Hmo6BoV0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_O73wBX98_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_91sk2V5X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Fk4KiUhD, HV_BINOP_MULTIPLY, 1, m, &cBinop_Fk4KiUhD_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_J7gCK2I1_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_P9SSFtGk, HV_BINOP_MULTIPLY, 1, m, &cBinop_P9SSFtGk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_02S9jfs6_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_1VNiKn07_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_KX9ak6pE, m);
  sVarf_onMessage(_c, &Context(_c)->sVarf_1A3Vwm0G, m);
}

void Heavy_WSTD_DL3Y::cReceive_egyAwq39_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_rGpLx37j_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_8tzQf64h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_yfNEi0xX_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_wPbN32hU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UVn2p2BT, HV_BINOP_MULTIPLY, 1, m, &cBinop_UVn2p2BT_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Tiy213rh_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_eoTNAHKC, HV_BINOP_MULTIPLY, 1, m, &cBinop_eoTNAHKC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3Mc478o5_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_38OO88lJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_3u9p6ATb, m);
  sVarf_onMessage(_c, &Context(_c)->sVarf_fYZFrxkc, m);
}

void Heavy_WSTD_DL3Y::cReceive_6aXlfFpa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_IpyPBIuW_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_WDa7pQAv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_KBawkOqd_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_ljlY3iJS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yjLQMjOP, HV_BINOP_MULTIPLY, 1, m, &cBinop_yjLQMjOP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pKhcU4hB_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_7SPdBQ8H, HV_BINOP_MULTIPLY, 1, m, &cBinop_7SPdBQ8H_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QoItzTQF_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_wNZk3dA6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_7BBxDAhS, m);
  sVarf_onMessage(_c, &Context(_c)->sVarf_8vtgrIRv, m);
}

void Heavy_WSTD_DL3Y::cReceive_nJFkh0pW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_OcJ4vP2m_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_W5VFado3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_Qr17Vws5_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_MJVYJBVc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PFBMaJEw, 0, m, &cVar_PFBMaJEw_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_5Z3D4Qmk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_POgMvsVH, 0, m, &cVar_POgMvsVH_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_YQgm7aSg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_cQe4j39W, 0, m, &cVar_cQe4j39W_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_qabnue4w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_cjXW0dFB, 0, m, &cVar_cjXW0dFB_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_Zqw8llW0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_BcvNmYES, 0, m, &cVar_BcvNmYES_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_SmqJZaab_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_X3UyUhOh, 0, m, &cVar_X3UyUhOh_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_5hPuBfks_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_f6VxDIRT, 0, m, &cVar_f6VxDIRT_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_cTlYKZLS, 0, m, &cVar_cTlYKZLS_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_2kdp05y7, 0, m, &cVar_2kdp05y7_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_sGXL4NVz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Eht9pcEl_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cReceive_7QsPqQGX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Z8sBiUJL_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cReceive_dXm8qvLS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_VtiL81uq_onMessage(_c, NULL, 0, m, NULL);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_DL3Y::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9, Bf10, Bf11, Bf12, Bf13;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_line_f(&sLine_kJh0SaDR, VOf(Bf0));
    __hv_line_f(&sLine_3rZMlBZo, VOf(Bf1));
    __hv_line_f(&sLine_LJQWHNTj, VOf(Bf2));
    __hv_line_f(&sLine_tGrr9cPb, VOf(Bf3));
    __hv_line_f(&sLine_vXzyv70z, VOf(Bf4));
    __hv_biquad_f(&sBiquad_s_iH3q8acw, VIf(I0), VIf(Bf0), VIf(Bf1), VIf(Bf2), VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_4BUwEWtU, VOf(Bf3));
    __hv_mul_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_7T7RPtZX, VOf(Bf4));
    __hv_zero_f(VOf(Bf2));
    __hv_line_f(&sLine_8Ibo082F, VOf(Bf1));
    __hv_line_f(&sLine_HD68qRAu, VOf(Bf0));
    __hv_line_f(&sLine_2OdqylDk, VOf(Bf5));
    __hv_biquad_f(&sBiquad_s_4bkPUMBw, VIf(I0), VIf(Bf4), VIf(Bf2), VIf(Bf1), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_znI3yxIM, VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_39iA6lvR, VOf(Bf5));
    __hv_line_f(&sLine_2OwiFIU4, VOf(Bf1));
    __hv_line_f(&sLine_Hur7B5gv, VOf(Bf2));
    __hv_line_f(&sLine_C5qy58mo, VOf(Bf4));
    __hv_line_f(&sLine_8PYhkDAo, VOf(Bf6));
    __hv_biquad_f(&sBiquad_s_8ghEZtJt, VIf(I0), VIf(Bf5), VIf(Bf1), VIf(Bf2), VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_cXX7VPBI, VOf(Bf4));
    __hv_mul_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_eXhDUNtk, VOf(Bf6));
    __hv_line_f(&sLine_D1JuR0s9, VOf(Bf2));
    __hv_line_f(&sLine_vwerc7LU, VOf(Bf1));
    __hv_line_f(&sLine_SOrwhjhI, VOf(Bf5));
    __hv_line_f(&sLine_1I0JV0CW, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_rPaoWpTN, VIf(I1), VIf(Bf6), VIf(Bf2), VIf(Bf1), VIf(Bf5), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_kDmdw5sM, VOf(Bf5));
    __hv_mul_f(VIf(Bf7), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_tMVolzDU, VOf(Bf7));
    __hv_zero_f(VOf(Bf1));
    __hv_line_f(&sLine_v3YC6iS3, VOf(Bf2));
    __hv_line_f(&sLine_JciVd4YJ, VOf(Bf6));
    __hv_line_f(&sLine_ReJFyme2, VOf(Bf8));
    __hv_biquad_f(&sBiquad_s_4aoTeWS9, VIf(I1), VIf(Bf7), VIf(Bf1), VIf(Bf2), VIf(Bf6), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_aJqNvZb4, VOf(Bf6));
    __hv_mul_f(VIf(Bf8), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_W71E820s, VOf(Bf8));
    __hv_line_f(&sLine_SKZfHngI, VOf(Bf2));
    __hv_line_f(&sLine_7VUakwb1, VOf(Bf1));
    __hv_line_f(&sLine_6J7Y9NNA, VOf(Bf7));
    __hv_line_f(&sLine_ZZ007Gc4, VOf(Bf9));
    __hv_biquad_f(&sBiquad_s_2Pu1Sj2P, VIf(I1), VIf(Bf8), VIf(Bf2), VIf(Bf1), VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_d6xR9yDw, VOf(Bf7));
    __hv_mul_f(VIf(Bf9), VIf(Bf7), VOf(Bf7));
    __hv_line_f(&sLine_QUo1G4gS, VOf(Bf9));
    __hv_tabread_f(&sTabread_jCyYXfUp, VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf8), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_wxptlJJc, VOf(Bf2));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_fma_f(VIf(Bf3), VIf(Bf9), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_JB0Xe7Ux, VOf(Bf9));
    __hv_tabread_f(&sTabread_gumrO5pJ, VOf(Bf8));
    __hv_var_k_f(VOf(Bf10), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf8), VIf(Bf10), VOf(Bf10));
    __hv_var_k_f(VOf(Bf11), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_line_f(&sLine_U9Cfb8gy, VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_fma_f(VIf(Bf5), VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_jxnIX1t7, VOf(Bf9));
    __hv_add_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_2WmMyujj, VOf(Bf3));
    __hv_rpole_f(&sRPole_9RgIJVyK, VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_var_k_f(VOf(Bf9), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_0uuBOuoz, VIf(Bf3), VOf(Bf11));
    __hv_mul_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_sub_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_q9rV8ZfT, VOf(Bf3));
    __hv_mul_f(VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_tabwrite_f(&sTabwrite_bl2DJOVj, VIf(Bf3));
    __hv_varread_f(&sVarf_M0aDGRLh, VOf(Bf3));
    __hv_add_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_GOw4Ag0B, VOf(Bf5));
    __hv_rpole_f(&sRPole_bwXX3iP6, VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf3), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_SddVIMQI, VIf(Bf5), VOf(Bf9));
    __hv_mul_f(VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_xQhBofaa, VOf(Bf5));
    __hv_mul_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_tabwrite_f(&sTabwrite_4yWDat1p, VIf(Bf5));
    __hv_varread_f(&sVarf_KX9ak6pE, VOf(Bf5));
    __hv_mul_f(VIf(Bf1), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_gKmidHOR, VOf(Bf1));
    __hv_varread_f(&sVarf_1A3Vwm0G, VOf(Bf3));
    __hv_mul_f(VIf(Bf8), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_yENWJgcS, VOf(Bf8));
    __hv_mul_f(VIf(Bf3), VIf(Bf8), VOf(Bf8));
    __hv_fma_f(VIf(Bf5), VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_6QUsvZ3b, VOf(Bf1));
    __hv_varread_f(&sVarf_PufPqmnj, VOf(Bf9));
    __hv_mul_f(VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_UPTvDAyt, VOf(Bf1));
    __hv_rpole_f(&sRPole_FUsJuoDb, VIf(Bf9), VIf(Bf1), VOf(Bf1));
    __hv_mul_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    sEnv_process(this, &sEnv_G3Y4FPrS, VIf(Bf8), &sEnv_G3Y4FPrS_sendMessage);
    __hv_varread_f(&sVarf_GGZvI91M, VOf(Bf8));
    __hv_mul_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_ybxY8DX1, VOf(Bf1));
    __hv_rpole_f(&sRPole_wXo36che, VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_varwrite_f(&sVarf_jxnIX1t7, VIf(Bf1));
    __hv_line_f(&sLine_TptN4Ux4, VOf(Bf1));
    __hv_line_f(&sLine_Smhz4MkN, VOf(Bf8));
    __hv_mul_f(VIf(Bf5), VIf(Bf8), VOf(Bf8));
    __hv_fma_f(VIf(Bf3), VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_ncBUKKHR, VOf(Bf1));
    __hv_varread_f(&sVarf_p3X47L0v, VOf(Bf3));
    __hv_mul_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_RBN38R9K, VOf(Bf1));
    __hv_rpole_f(&sRPole_ZdFfhGA4, VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_mul_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    sEnv_process(this, &sEnv_DusZaa7A, VIf(Bf8), &sEnv_DusZaa7A_sendMessage);
    __hv_varread_f(&sVarf_oWhjsW4v, VOf(Bf8));
    __hv_mul_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_XZgxXwpV, VOf(Bf1));
    __hv_rpole_f(&sRPole_1RO4mIhQ, VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_varwrite_f(&sVarf_M0aDGRLh, VIf(Bf1));
    __hv_varwrite_f(&sVarf_EXzUW1i4, VIf(Bf2));
    __hv_varread_f(&sVarf_kJcHolcm, VOf(Bf2));
    __hv_varread_f(&sVarf_fVzWGxEH, VOf(Bf1));
    __hv_line_f(&sLine_PLysKHh7, VOf(Bf8));
    __hv_tabread_f(&sTabread_x2U2t9Yg, VOf(Bf3));
    __hv_var_k_f(VOf(Bf5), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf9), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf5), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_P1OdeSXT, VOf(Bf5));
    __hv_mul_f(VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_fma_f(VIf(Bf2), VIf(Bf8), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_dxPE8zkt, VOf(Bf8));
    __hv_tabread_f(&sTabread_ofzDWlSh, VOf(Bf9));
    __hv_var_k_f(VOf(Bf11), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf12), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_line_f(&sLine_u6DLfBsS, VOf(Bf11));
    __hv_mul_f(VIf(Bf12), VIf(Bf11), VOf(Bf11));
    __hv_fma_f(VIf(Bf1), VIf(Bf8), VIf(Bf11), VOf(Bf11));
    __hv_varread_f(&sVarf_g6ERgTmd, VOf(Bf8));
    __hv_add_f(VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_dfD9NjQc, VOf(Bf2));
    __hv_rpole_f(&sRPole_xktuHp75, VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf8), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_CaARGbMB, VIf(Bf2), VOf(Bf12));
    __hv_mul_f(VIf(Bf12), VIf(Bf8), VOf(Bf8));
    __hv_sub_f(VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_0JFkmAVK, VOf(Bf2));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_tabwrite_f(&sTabwrite_ss27HoFU, VIf(Bf2));
    __hv_varread_f(&sVarf_QADJ3qC3, VOf(Bf2));
    __hv_add_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_ES8wOcWX, VOf(Bf1));
    __hv_rpole_f(&sRPole_nVyVfIfG, VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_JZYAJ2WN, VIf(Bf1), VOf(Bf8));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_Sor2xfXa, VOf(Bf1));
    __hv_mul_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_tabwrite_f(&sTabwrite_41AIsxpP, VIf(Bf1));
    __hv_varread_f(&sVarf_3u9p6ATb, VOf(Bf1));
    __hv_mul_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_8LHM389H, VOf(Bf3));
    __hv_varread_f(&sVarf_fYZFrxkc, VOf(Bf2));
    __hv_mul_f(VIf(Bf9), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_XmaejfVE, VOf(Bf9));
    __hv_mul_f(VIf(Bf2), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf1), VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_c2ai5P5T, VOf(Bf3));
    __hv_varread_f(&sVarf_XzGRbfNn, VOf(Bf8));
    __hv_mul_f(VIf(Bf3), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_U4O6tKli, VOf(Bf3));
    __hv_rpole_f(&sRPole_KwHRoUpg, VIf(Bf8), VIf(Bf3), VOf(Bf3));
    __hv_mul_f(VIf(Bf9), VIf(Bf3), VOf(Bf3));
    sEnv_process(this, &sEnv_xvFSZtWZ, VIf(Bf9), &sEnv_xvFSZtWZ_sendMessage);
    __hv_varread_f(&sVarf_dvSTIikI, VOf(Bf9));
    __hv_mul_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_e3gGVxVd, VOf(Bf3));
    __hv_rpole_f(&sRPole_7hjTthTM, VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_varwrite_f(&sVarf_g6ERgTmd, VIf(Bf3));
    __hv_line_f(&sLine_Kn7buoVW, VOf(Bf3));
    __hv_line_f(&sLine_xKGSX7HE, VOf(Bf9));
    __hv_mul_f(VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf2), VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_CKLGQAB3, VOf(Bf3));
    __hv_varread_f(&sVarf_9Dn7f0SQ, VOf(Bf2));
    __hv_mul_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_sGj9JT6t, VOf(Bf3));
    __hv_rpole_f(&sRPole_oIlmLN5h, VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_mul_f(VIf(Bf9), VIf(Bf3), VOf(Bf3));
    sEnv_process(this, &sEnv_cj5rytmK, VIf(Bf9), &sEnv_cj5rytmK_sendMessage);
    __hv_varread_f(&sVarf_Q2WXAtNx, VOf(Bf9));
    __hv_mul_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_VAdL1307, VOf(Bf3));
    __hv_rpole_f(&sRPole_38SaWtO1, VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_varwrite_f(&sVarf_QADJ3qC3, VIf(Bf3));
    __hv_varwrite_f(&sVarf_a6XN91ud, VIf(Bf5));
    __hv_varread_f(&sVarf_DutPA6ob, VOf(Bf5));
    __hv_varread_f(&sVarf_9sTivhHL, VOf(Bf3));
    __hv_line_f(&sLine_EqXIZ3nf, VOf(Bf9));
    __hv_tabread_f(&sTabread_EhqIz5NI, VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf8), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_9NHUefnY, VOf(Bf1));
    __hv_mul_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_fma_f(VIf(Bf5), VIf(Bf9), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_7VwmSCXX, VOf(Bf9));
    __hv_tabread_f(&sTabread_lMZcOwpF, VOf(Bf8));
    __hv_var_k_f(VOf(Bf12), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf8), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf13), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_line_f(&sLine_9BxoFLfS, VOf(Bf12));
    __hv_mul_f(VIf(Bf13), VIf(Bf12), VOf(Bf12));
    __hv_fma_f(VIf(Bf3), VIf(Bf9), VIf(Bf12), VOf(Bf12));
    __hv_varread_f(&sVarf_U4oOBMua, VOf(Bf9));
    __hv_add_f(VIf(Bf5), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_xEOxzlSI, VOf(Bf5));
    __hv_rpole_f(&sRPole_lHtpClCG, VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf9), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_NQs5q9Wy, VIf(Bf5), VOf(Bf13));
    __hv_mul_f(VIf(Bf13), VIf(Bf9), VOf(Bf9));
    __hv_sub_f(VIf(Bf5), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_Mey2ASBG, VOf(Bf5));
    __hv_mul_f(VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_tabwrite_f(&sTabwrite_MLrMEAIn, VIf(Bf5));
    __hv_varread_f(&sVarf_QuuU7Onv, VOf(Bf5));
    __hv_add_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_CzKj2tcE, VOf(Bf3));
    __hv_rpole_f(&sRPole_Yw3t4j0K, VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_var_k_f(VOf(Bf5), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_7fqCVLk2, VIf(Bf3), VOf(Bf9));
    __hv_mul_f(VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_sub_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_8FkfIvOI, VOf(Bf3));
    __hv_mul_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_tabwrite_f(&sTabwrite_bbqCH68Y, VIf(Bf3));
    __hv_varread_f(&sVarf_7BBxDAhS, VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_KkmMQoEr, VOf(Bf2));
    __hv_varread_f(&sVarf_8vtgrIRv, VOf(Bf5));
    __hv_mul_f(VIf(Bf8), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_ebHEI9Se, VOf(Bf8));
    __hv_mul_f(VIf(Bf5), VIf(Bf8), VOf(Bf8));
    __hv_fma_f(VIf(Bf3), VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_6vPnDkx4, VOf(Bf2));
    __hv_varread_f(&sVarf_kWbeYKlB, VOf(Bf9));
    __hv_mul_f(VIf(Bf2), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_FysH86lk, VOf(Bf2));
    __hv_rpole_f(&sRPole_PqptoNrE, VIf(Bf9), VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    sEnv_process(this, &sEnv_j98bGlBF, VIf(Bf8), &sEnv_j98bGlBF_sendMessage);
    __hv_varread_f(&sVarf_eSQ9AtSo, VOf(Bf8));
    __hv_mul_f(VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_ezNDdIIq, VOf(Bf2));
    __hv_rpole_f(&sRPole_otrXE8X6, VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_U4oOBMua, VIf(Bf2));
    __hv_line_f(&sLine_mwRC6e9e, VOf(Bf2));
    __hv_line_f(&sLine_My6wt8xb, VOf(Bf8));
    __hv_mul_f(VIf(Bf3), VIf(Bf8), VOf(Bf8));
    __hv_fma_f(VIf(Bf5), VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_QEkxL30X, VOf(Bf2));
    __hv_varread_f(&sVarf_TAY4jR9W, VOf(Bf5));
    __hv_mul_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_uli9YSYT, VOf(Bf2));
    __hv_rpole_f(&sRPole_FWZQa5dY, VIf(Bf5), VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    sEnv_process(this, &sEnv_HHaHgeMa, VIf(Bf8), &sEnv_HHaHgeMa_sendMessage);
    __hv_varread_f(&sVarf_Zb1HqML6, VOf(Bf8));
    __hv_mul_f(VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_qqArUhbb, VOf(Bf2));
    __hv_rpole_f(&sRPole_lrVBjNas, VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_QuuU7Onv, VIf(Bf2));
    __hv_varwrite_f(&sVarf_rexWg1zb, VIf(Bf1));
    __hv_varwrite_f(&sVarf_orsFTQor, VIf(Bf10));
    __hv_varwrite_f(&sVarf_b9EtPQyV, VIf(Bf11));
    __hv_varwrite_f(&sVarf_7fvWIELW, VIf(Bf12));
    __hv_varwrite_f(&sVarf_kJcHolcm, VIf(Bf0));
    __hv_varwrite_f(&sVarf_fVzWGxEH, VIf(Bf6));
    __hv_varwrite_f(&sVarf_DutPA6ob, VIf(Bf4));
    __hv_varwrite_f(&sVarf_9sTivhHL, VIf(Bf7));
    __hv_varread_f(&sVarf_orsFTQor, VOf(Bf7));
    __hv_varread_f(&sVarf_b9EtPQyV, VOf(Bf4));
    __hv_varread_f(&sVarf_7fvWIELW, VOf(Bf6));
    __hv_add_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_add_f(VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_add_f(VIf(Bf6), VIf(O1), VOf(O1));
    __hv_varread_f(&sVarf_EXzUW1i4, VOf(Bf6));
    __hv_varread_f(&sVarf_a6XN91ud, VOf(Bf7));
    __hv_varread_f(&sVarf_rexWg1zb, VOf(Bf4));
    __hv_add_f(VIf(Bf7), VIf(Bf4), VOf(Bf4));
    __hv_add_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_add_f(VIf(Bf4), VIf(O0), VOf(O0));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_DL3Y::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_DL3Y::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
